#*******************************************************
#*******************************************************
# SCRP data and hydroTSM and zoo packages
# 
#
#*******************************************************
#*******************************************************
# example is done with Anjeni, but can be done with any SCRP station
# the format of the input data must be

library(ggplot2)
library(zoo)
library(EcoHydRology)
library(hydroTSM)
library(hydroGOF)
library(TTR)
library(seas)
library(gplots)
detach("package:timeSeries")
detach("package:timeDate")
#*******************************************************************************
#*******************************************************************************
#****************************       Load data            ***********************
#*******************************************************************************
# Andit Tid
wdAT <- "DataCFSR/3_AnditTid"
# Daily data
setwd(wdAT)
AT.d.cfsr <- read.csv("pcp_4_St_.csv", header=TRUE, sep=",", na.strings="NA")
AT.d.cfsr$date <- as.Date(AT.d.cfsr$date, format="%Y-%m-%d")
AT.d.scrp <- read.csv("ATAllpcp.csv", header=TRUE, sep=",", na.strings="-99")
AT.d.scrp$date <- as.Date(AT.d.scrp$date, format="%m/%d/%Y")

# Anjeni
wdAJ <- "DataCFSR/1_Anjeni"
# Daily data
setwd(wdAJ)
AJ.d.cfsr <- read.csv("pcp_4_St_.csv", header=TRUE, sep=",", na.strings="NA")
AJ.d.cfsr$date <- as.Date(AJ.d.cfsr$date, format="%Y-%m-%d")
AJ.d.scrp <- read.csv("AJAllpcp.csv", header=TRUE, sep=",", na.strings="-99")
AJ.d.scrp$date <- as.Date(AJ.d.scrp$date, format="%m/%d/%Y")

# Maybar
wdMA <- "DataCFSR/2_Maybar"
# Daily data
setwd(wdMA)
MA.d.cfsr <- read.csv("pcp_6_St_.csv", header=TRUE, sep=",", na.strings="NA")
MA.d.cfsr$date <- as.Date(MA.d.cfsr$date, format="%Y-%m-%d")
MA.d.scrp <- read.csv("MAAllpcp.csv", header=TRUE, sep=",", na.strings="-99")
MA.d.scrp$date <- as.Date(MA.d.scrp$date, format="%m/%d/%Y")


#*******************************************************************************
#*******************************************************************************


# Create a zoo object from the rainfall data
at.zoo <- read.zoo(AT.d.scrp, sep=",", format="%Y-%m-%d")
aj.zoo <- read.zoo(AJ.d.scrp, sep=",", format="%Y-%m-%d")
ma.zoo <- read.zoo(MA.d.scrp, sep=",", format="%Y-%m-%d")


at.ts.day <- ts(AT.d.scrp$pcp, freq=365, start=c(1982,1,1))
aj.ts.day <- ts(AJ.d.scrp$pcp, freq=365, start=c(1984,1,1))
ma.ts.day <- ts(MA.d.scrp$pcp, freq=365, start=c(1981,1,1))

#*******************************************************************************
# Aggregate the daily data to monthly data----
at.month <- daily2monthly(at.zoo, FUN=sum, na.rm=FALSE)
aj.month <- daily2monthly(aj.zoo, FUN=sum, na.rm=FALSE)
ma.month <- daily2monthly(ma.zoo, FUN=sum, na.rm=FALSE)

# create an ordered ts object----
at.month.ts <- ts(at.month, freq=12, start=c(1982,1))
aj.month.ts <- ts(aj.month, freq=12, start=c(1984,1))
ma.month.ts <- ts(ma.month, freq=12, start=c(1981,1))

# date ----
at.dates <- time(at.zoo)
aj.dates <- time(aj.zoo)
ma.dates <- time(ma.zoo)


# Number of years----
at.nyrs <- yip(from=start(at.zoo), to=end(at.zoo), out.type="nmbr")
aj.nyrs <- yip(from=start(aj.zoo), to=end(aj.zoo), out.type="nmbr")
ma.nyrs <- yip(from=start(ma.zoo), to=end(ma.zoo), out.type="nmbr")
# Summary----
all.smry <- cbind(AT=smry(coredata(at.zoo)), AJ=smry(coredata(aj.zoo)), 
                  MA=smry(coredata(ma.zoo)))
names(all.smry) <- c("AT", "AJ","MA")


# Creating a matrix with monthly values per year in each column----
# ANDIT TID
at.Matrix <- matrix(at.month, ncol=12, byrow=T)
colnames(at.Matrix) <- month.abb
rownames(at.Matrix) <- unique(format(time(at.month), "%Y"))
# ANJENI
aj.Matrix <- matrix(aj.month, ncol=12, byrow=T)
colnames(aj.Matrix) <- month.abb
rownames(aj.Matrix) <- unique(format(time(aj.month), "%Y"))
# MAYBAR
ma.Matrix <- matrix(ma.month, ncol=12, byrow=T)
colnames(ma.Matrix) <- month.abb
rownames(ma.Matrix) <- unique(format(time(ma.month), "%Y"))



# Annual Analysis----

all.yrly.scrp <- as.data.frame(cbind((daily2annual(at.zoo, FUN=sum, na.rm=TRUE)),
                                (daily2annual(aj.zoo, FUN=sum, na.rm=TRUE)),
                                (daily2annual(ma.zoo, FUN=sum, na.rm=TRUE))))
names(all.yrly.scrp) <- c("AT", "AJ","MA")

at.yrly <- daily2annual(at.zoo, FUN=sum, na.rm=FALSE)
# index(at.yrly) <- format(index(at.yrly), "%Y")
aj.yrly <- daily2annual(aj.zoo, FUN=sum, na.rm=FALSE)
# index(aj.yrly) <- format(index(aj.yrly), "%Y")
ma.yrly <- daily2annual(ma.zoo, FUN=sum, na.rm=FALSE)
# index(ma.yrly) <- format(index(ma.yrly), "%Y")


# Mean value of all mean values of all years
all.yrly.mean.scrp <- as.data.frame(cbind(annualfunction(at.zoo, FUN=sum, na.rm=TRUE)/at.nyrs,
                                     annualfunction(aj.zoo, FUN=sum, na.rm=TRUE)/aj.nyrs,
                                     annualfunction(ma.zoo, FUN=sum, na.rm=TRUE)/ma.nyrs))
names(all.yrly.mean.scrp) <- c("AT", "AJ","MA")
row.names(all.yrly.mean.scrp) <- "Mean yrly precip"


#***************************************************
# pdf(file="W:/10_Papers/11_OwnPapers/Graphs/MonthlyData.pdf", 
#     width=1200, height=600, paper="a4r")

# Monthly Analysis----
# Andit Tid
par(mai=c(1.4,1,1.4,0.5))
at.med.month <- monthlyfunction(at.month, FUN=median, na.rm=T)
at.mean.month <- monthlyfunction(at.month, FUN="mean", na.rm=T)
at.cmonth <- format(time(at.month), "%b")
at.months <- factor(at.cmonth, level=unique(at.cmonth), ordered=T)

par(mfrow=c(1,3))
yl <- seq(0,600, 50)
xl <- seq(1,12,1)
boxplot(coredata(at.month)~at.months, col="lightblue", 
        main="Monthly precipitation distribution \nAndit Tid (1984-2004)",
        ylab="Precipitation [mm]", xaxt="n", yaxt="n")
axis(1, seq(1,12,1), month.abb, las=2)
axis(2, yl, yl, las=2, cex=.8)
abline(h=yl, v=xl, col="lightgrey", lty=3)
abline(h=mean(at.mean.month), col="brown", lty=2)
text(0.03, 550, paste("Monthly mean: ", round(mean(at.mean.month),2)," mm"),
     pos=4, cex=.8)
text(0.03, 530, paste("Monthly mean max: ", round(max(at.mean.month),2), "mm"),
     pos=4, cex=.8)
text(0.03, 510, paste("Monthly mean min: ", round(min(at.mean.month), 2), "mm"), 
     pos=4, cex=.8)

# Add Anjeni
aj.med.month <- monthlyfunction(aj.month, FUN=median, na.rm=T)
aj.mean.month <- monthlyfunction(aj.month, FUN="mean", na.rm=T)
aj.cmonth <- format(time(aj.month), "%b")
aj.months <- factor(aj.cmonth, level=unique(aj.cmonth), ordered=T) 

boxplot(coredata(aj.month)~aj.months, col="lightblue", 
        main="Monthly precipitation distribution \nAnjeni (1984-2004)",
        ylab="Precipitation [mm]", xaxt="n", yaxt="n")
axis(1, seq(1,12,1), month.abb, las=2)
axis(2, yl, yl, las=2, cex=.8)
abline(h=yl, v=xl, col="lightgrey", lty=3)
abline(h=mean(aj.mean.month), col="brown", lty=2)
text(0.03, 550, paste("Monthly mean: ", round(mean(aj.mean.month),2)," mm"),
     pos=4, cex=.8)
text(0.03, 530, paste("Monthly mean max: ", round(max(aj.mean.month),2), "mm"),
     pos=4, cex=.8)
text(0.03, 510, paste("Monthly mean min: ", round(min(aj.mean.month), 2), "mm"), 
     pos=4, cex=.8)

# Add Maybar
ma.med.month <- monthlyfunction(ma.month, FUN=median, na.rm=T)
ma.mean.month <- monthlyfunction(ma.month, FUN="mean", na.rm=T)
ma.cmonth <- format(time(ma.month), "%b")
ma.months <- factor(ma.cmonth, level=unique(ma.cmonth), ordered=T) 

boxplot(coredata(ma.month)~ma.months, col="lightblue", 
        main="Monthly precipitation distribution \nMaybar (1984-2004)",
        ylab="Precipitation [mm]", xaxt="n", yaxt="n")
axis(1, seq(1,12,1), month.abb, las=2)
axis(2, yl, yl, las=2, cex=.8)
abline(h=yl, v=xl, col="lightgrey", lty=3)
abline(h=mean(ma.mean.month), col="brown", lty=2)
text(0.03, 550, paste("Monthly mean: ", round(mean(ma.mean.month),2)," mm"),
     pos=4, cex=.8)
text(0.03, 530, paste("Monthly mean max: ", round(max(ma.mean.month),2), "mm"),
     pos=4, cex=.8)
text(0.03, 510, paste("Monthly mean min: ", round(min(ma.mean.month), 2), "mm"), 
     pos=4, cex=.8)

par(mfrow=c(1,1))


#******************************************************************************
#******************************************************************************
# Comparing the SCRP data to the CFSR----
#******************************************************************************
# Andit Tid
setwd(wdAT)
ATallNNR <- read.csv("pcpNNRAll.csv", header=T, sep=",", na.strings="-99")
ATallNNR$date <- as.Date(ATallNNR$date, format="%m/%d/%Y")
ATallNNR$Mean <- rowMeans(ATallNNR[,c(2:5)])
ATallNNR <- ATallNNR[,c(1,6)]
# Anjeni
setwd(wdAJ)
AJallNNR <- read.csv("pcpNNRAll.csv", header=T, sep=",", na.strings="-99")
AJallNNR$date <- as.Date(AJallNNR$date, format="%m/%d/%Y")
AJallNNR$Mean <- rowMeans(AJallNNR[,c(2:5)])
AJallNNR <- AJallNNR[,c(1,6)]
# Maybar
setwd(wdMA)
MAallNNR <- read.csv("pcpNNRAll.csv", header=T, sep=",", na.strings="-99")
MAallNNR$date <- as.Date(MAallNNR$date, format="%m/%d/%Y")
MAallNNR$Mean <- rowMeans(MAallNNR[,c(2:7)])
MAallNNR <- MAallNNR[,c(1,8)]
# rm(wdAJ, wdAT, wdMA)

# Create a zoo object from the rainfall data
ATnnr.zoo <- read.zoo(ATallNNR, sep=",", format="%Y-%m-%d")
AJnnr.zoo <- read.zoo(AJallNNR, sep=",", format="%Y-%m-%d")
MAnnr.zoo <- read.zoo(MAallNNR, sep=",", format="%Y-%m-%d")

# dates from NNR data
ATdates.nnr <- time(ATnnr.zoo)
ATnyrs.nnr <- yip(from=start(ATnnr.zoo), to=end(ATnnr.zoo), out.type="nmbr")
AJdates.nnr <- time(AJnnr.zoo)
AJnyrs.nnr <- yip(from=start(AJnnr.zoo), to=end(AJnnr.zoo), out.type="nmbr")
MAdates.nnr <- time(MAnnr.zoo)
MAnyrs.nnr <- yip(from=start(MAnnr.zoo), to=end(MAnnr.zoo), out.type="nmbr")


#summary----
all.smry <- cbind(all.smry, smry(coredata(ATnnr.zoo)),smry(coredata(AJnnr.zoo)),
                     smry(coredata(MAnnr.zoo)))
names(all.smry) <- c("AT", "AJ","MA","ATNNR", "AJNNR","MANNR")

all.smry <- round(all.smry, 2)

# Export yearly statistics to word----
# library(R2wd)
# wdTable(all.smry, caption="Summary of SCRP and CFSR data", 
#         caption.pos="above", pointsize=9, 
#         align=c("r"))



# Plotting monthly precipitation values for each year----
# daily zoo to monthly zoo
ATnnr.m <- daily2monthly(ATnnr.zoo, FUN=sum, na.rm=FALSE)
AJnnr.m <- daily2monthly(AJnnr.zoo, FUN=sum, na.rm=FALSE)
MAnnr.m <- daily2monthly(MAnnr.zoo, FUN=sum, na.rm=FALSE)

# Create an ordered monthly ts object
ATnnr.ts <- ts(ATnnr.m, freq=12, start=c(1979,1))
AJnnr.ts <- ts(AJnnr.m, freq=12, start=c(1979,1))
MAnnr.ts <- ts(MAnnr.m, freq=12, start=c(1979,1))

# Creating matrix with monthly values per year in each column----
# nnr1
at.Matrixnnr <- matrix(ATnnr.m, ncol=12, byrow=T)
colnames(at.Matrixnnr) <- month.abb
rownames(at.Matrixnnr) <- unique(format(time(ATnnr.m),"%Y"))
aj.Matrixnnr <- matrix(AJnnr.m, ncol=12, byrow=T)
colnames(aj.Matrixnnr) <- month.abb
rownames(aj.Matrixnnr) <- unique(format(time(AJnnr.m),"%Y"))
ma.Matrixnnr<- matrix(MAnnr.m, ncol=12, byrow=T)
colnames(ma.Matrixnnr) <- month.abb
rownames(ma.Matrixnnr) <- unique(format(time(MAnnr.m),"%Y"))


# Matrixplot the data from NNR----
# Andit Tid
matrixplot(at.Matrixnnr, ColorRamp="Precipitation", 
           main="Monthly Precipitation distribution\n Andit Tid CFSR, [mm/month]")
matrixplot(at.Matrix, ColorRamp="Precipitation", 
           main="Monthly Precipitation distribution\n Andit Tid SCRP, [mm/month]")
# Anjeni
matrixplot(aj.Matrixnnr, ColorRamp="Precipitation", 
           main="Monthly Precipitation distribution\n Anjeni CFSR, [mm/month]")
matrixplot(aj.Matrix, ColorRamp="Precipitation", 
           main="Monthly Precipitation distribution\n Anjeni SCRP [mm/month]")
# Maybar
matrixplot(ma.Matrixnnr, ColorRamp="Precipitation", 
           main="Monthly Precipitation distribution\n Maybar CFSR, [mm/month]")
matrixplot(ma.Matrix, ColorRamp="Precipitation", 
           main="Monthly Precipitation distribution\n Maybar SCRP, [mm/month]")



#*******************************************************************************
#*******************************************************************************
# Number of years----
at.nyrs.nnr <- yip(from=start(ATnnr.zoo), to=end(ATnnr.zoo), out.type="nmbr")
aj.nyrs.nnr <- yip(from=start(AJnnr.zoo), to=end(AJnnr.zoo), out.type="nmbr")
ma.nyrs.nnr <- yip(from=start(MAnnr.zoo), to=end(MAnnr.zoo), out.type="nmbr")

#******************************************************************************3
# Create MEAN yearly sums of NNR----
ATnnr.yrly <- (daily2annual(ATnnr.zoo, FUN=sum, na.rm=TRUE))
ATnnr.mean.yr <- annualfunction(ATnnr.zoo, FUN=sum, na.rm=T)/at.nyrs.nnr

AJnnr.yrly <- (daily2annual(AJnnr.zoo, FUN=sum, na.rm=T))
AJnnr.mean.yr <- annualfunction(AJnnr.zoo, FUN=sum, na.rm=T)/aj.nyrs.nnr

MAnnr.yrly <- (daily2annual(MAnnr.zoo, FUN=sum, na.rm=T))
MAnnr.mean.yr <- annualfunction(MAnnr.zoo, FUN=sum, na.rm=T)/ma.nyrs.nnr

#*******************************************************************************
# Monthly analysis
ATnnr.mo.med <- round(monthlyfunction(ATnnr.m, FUN=median, na.rm=T),2)
ATnnr.mo.mean <- round(monthlyfunction(ATnnr.m, FUN="mean", na.rm=T),2)

AJnnr.mo.med <- round(monthlyfunction(AJnnr.m, FUN=median, na.rm=T),2)
AJnnr.mo.mean <- round(monthlyfunction(AJnnr.m, FUN="mean", na.rm=T),2)

MAnnr.mo.med <- round(monthlyfunction(MAnnr.m, FUN=median, na.rm=T),2)
MAnnr.mo.mean <- round(monthlyfunction(MAnnr.m, FUN="mean", na.rm=T),2)

ATnnr.cmonth <- format(time(ATnnr.m), "%b")
ATnnr.months <- factor(ATnnr.cmonth, levels=unique(ATnnr.cmonth), ordered=T)
AJnnr.cmonth <- format(time(AJnnr.m), "%b")
AJnnr.months <- factor(AJnnr.cmonth, levels=unique(AJnnr.cmonth), ordered=TRUE)
MAnnr.cmonth <- format(time(MAnnr.m), "%b")
MAnnr.months <- factor(MAnnr.cmonth, levels=unique(MAnnr.cmonth), ordered=TRUE)


#*********************************************
# Boxplot Andit Tid CFSR----
max <- max(ATnnr.m, na.rm=TRUE)
yl <- seq(min(ATnnr.m, na.rm=TRUE), max+100, by=50)
boxplot(coredata(ATnnr.m)~ATnnr.months, col="lightblue", 
        main="Monhtly precipitation distribution \nAndit Tid CFSR (1979-2004)",
        ylab="Precipitation [mm]", xlab="", yaxt="n",
        ylim=c(0, max+100))
# lines(nnr.mo.mean1, col="red")
axis(2, yl, yl, las=2, cex=.8)
abline(v=time(ATnnr.mo.mean), col="lightgrey", lty=3)
abline(h=yl, col="lightgray", lty=3)
abline(h=mean(ATnnr.mo.mean), col="brown", lty=2)
text(0.02, max+50, paste("Monthly mean max: ", round(max(ATnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)
text(0.02, max+35, paste("Monthly mean: ", round(mean(ATnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)
text(0.02, max+20, paste("Monthly mean min: ", round(min(ATnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)

#***********************************
# Boxplot Anjeni CFSR----
max <- max(AJnnr.m, na.rm=TRUE)
yl <- seq(min(AJnnr.m, na.rm=TRUE), max+100, by=50)
boxplot(coredata(AJnnr.m)~AJnnr.months, col="lightblue", 
        main="Monhtly precipitation distribution \nAnjeni CFSR (1979-2004)",
        ylab="Precipitation [mm]", xlab="", yaxt="n",
        ylim=c(0, max+100))
# lines(nnr.mo.mean1, col="red")
axis(2, yl, yl, las=2, cex=.8)
abline(v=time(AJnnr.mo.mean), col="lightgrey", lty=3)
abline(h=yl, col="lightgray", lty=3)
abline(h=mean(AJnnr.mo.mean), col="brown", lty=2)
text(0.02, max+50, paste("Monthly mean max: ", round(max(AJnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)
text(0.02, max+20, paste("Monthly mean: ", round(mean(AJnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)
text(0.02, max-10, paste("Monthly mean min: ", round(min(AJnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)

#***********************************
# Boxplot Maybar CFSR----
max <- max(ATnnr.m, na.rm=TRUE)
yl <- seq(min(ATnnr.m, na.rm=TRUE), max+100, by=50)
boxplot(coredata(ATnnr.m)~MAnnr.months, col="lightblue", 
        main="Monhtly precipitation distribution \nMaybar CFSR (1979-2004)",
        ylab="Precipitation [mm]", xlab="", yaxt="n",
        ylim=c(0, max+100))
# lines(nnr.mo.mean1, col="red")
axis(2, yl, yl, las=2, cex=.8)
abline(v=time(ATnnr.mo.mean), col="lightgrey", lty=3)
abline(h=yl, col="lightgray", lty=3)
abline(h=mean(ATnnr.mo.mean), col="brown", lty=2)
text(0.02, max+50, paste("Monthly mean max: ", round(max(ATnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)
text(0.02, max+35, paste("Monthly mean: ", round(mean(ATnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)
text(0.02, max+20, paste("Monthly mean min: ", round(min(ATnnr.mo.mean), 2), "mm"),
     pos=4, cex=0.8)




#******************************************************************************
#******************************************************************************
#******************************************************************************
# All 6 on one plot----
# png(file="E:/RainfallCompBoxplot.png", width=1500, height=2200, units="px")
# pdf(file="E:/RainfallBoxplot.pdf")
# layout.show(nf)
cairo_ps(file="E:/BoxplotAllCairo.eps", width = 8, height = 11, 
         onefile = FALSE, family = "Helvetica")
par(mfrow=c(3,2), mar=c(4, 6, 5, 2), oma=c(3,4,4,1))

# par(mfrow=c(3,2), mar=c(4,7,4,0.5))
# CFSR data in one row, SCRP data in the other row
max <- 600
yl <- seq(0,600, 50)
boxplot(coredata(ATnnr.m)~ATnnr.months, col="lightblue",
        ylab="", xlab="", yaxt="n", xaxt="n",
        ylim=c(0,600))
axis(1, seq(1,12,1), month.abb, las=2, cex.axis=2)
axis(2, yl, yl, las=2, cex.axis=1.6)
abline(v=time(ATnnr.mo.mean), col="lightgrey", lty=3)
abline(h=yl, col="lightgray", lty=3)
par(new=TRUE)
boxplot(coredata(ATnnr.m)~ATnnr.months, col="lightblue", 
        axes=FALSE, ylim=c(0,600))
abline(h=mean(ATnnr.mo.mean), col="brown", lty=2)
mtext(text="CFSR", 3, 2.5, cex=1.5)
mtext(text="Andit Tid", 3, .5)
# Andit Tid SCRP
boxplot(coredata(at.month)~at.months, col="olivedrab3",
        xaxt="n", yaxt="n", ylim=c(0,600))
axis(1, seq(1,12,1), month.abb, las=2, cex.axis=2)
axis(2, yl, yl, las=2, cex.axis=1.6)
abline(h=yl, v=time(ATnnr.mo.mean), col="lightgrey", lty=3)
par(new=TRUE)
boxplot(coredata(at.month)~at.months, col="olivedrab3", 
        axes=FALSE, ylim=c(0,600))
abline(h=mean(at.mean.month), col="brown", lty=2)
mtext(text="SCRP/WLRC", 3, 2.5, cex=1.5)
mtext("Andit Tid", 3, .5)
title(main="Precipitation distribution (1979-2010)", outer=TRUE, line=0.5,
      cex.main=3)

# Anjeni CFSR
yl <- seq(0,1300,100)
boxplot(coredata(AJnnr.m)~AJnnr.months, col="lightblue", 
        ylab="", xlab="", yaxt="n", xaxt="n",
        ylim=c(0,1300))
axis(1, seq(1,12,1), month.abb, las=2, cex.axis=2)
axis(2, yl, yl, las=2, cex.axis=1.6)
abline(v=time(AJnnr.mo.mean), col="lightgrey", lty=3)
abline(h=yl, col="lightgray", lty=3)
mtext("Anjeni", 3, .5)
par(new=TRUE)
boxplot(coredata(AJnnr.m)~AJnnr.months, col="lightblue", ylim=c(0,1300),
        axes=FALSE)
abline(h=mean(AJnnr.mo.mean), col="brown", lty=2)
mtext(text="Precipitation [mm]", 2, 6, cex=1.5)
# Anjeni SCRP
boxplot(coredata(aj.month)~aj.months, col="olivedrab3",
        xaxt="n", yaxt="n", ylim=c(0,1300))
axis(1, seq(1,12,1), month.abb, las=2, cex.axis=2)
axis(2, yl, yl, las=2, cex.axis=1.6)
abline(h=yl, v=time(AJnnr.mo.mean), col="lightgrey", lty=3)
mtext("Anjeni", 3, .5)
par(new=TRUE)
boxplot(coredata(aj.month)~aj.months, col="olivedrab3", ylim=c(0,1300),
        axes=FALSE)
abline(h=mean(aj.mean.month), col="brown", lty=2)

# Maybar CFSR
yl <- seq(0,650,50)
boxplot(coredata(MAnnr.m)~MAnnr.months, col="lightblue",
        ylab="", xlab="", yaxt="n", xaxt="n",
        ylim=c(0,600))
axis(1, seq(1,12,1), month.abb, las=2, cex.axis=2)
axis(2, yl, yl, las=2, cex.axis=1.6)
abline(v=time(MAnnr.mo.mean), col="lightgrey", lty=3)
abline(h=yl, col="lightgray", lty=3)
mtext("Maybar", 3, .5)
par(new=TRUE)
boxplot(coredata(MAnnr.m)~MAnnr.months, col="lightblue", ylim=c(0,600),
        axes=FALSE)
abline(h=mean(MAnnr.mo.mean), col="brown", lty=2)

# Maybar SCRP
boxplot(coredata(ma.month)~ma.months, col="olivedrab3",
        xaxt="n", yaxt="n", ylim=c(0,600))
axis(1, seq(1,12,1), month.abb, las=2, cex.axis=2)
axis(2, yl, yl, las=2, cex.axis=1.6)
abline(h=yl, v=time(MAnnr.mo.mean), col="lightgrey", lty=3)
mtext("Maybar", 3, .5)
par(new=TRUE)
boxplot(coredata(ma.month)~ma.months, col="olivedrab3", ylim=c(0,600),
        axes=FALSE)
abline(h=mean(ma.mean.month), col="brown", lty=2)
dev.off()


#*******************************************************************************
# Calculte statistics
library(psych)
library(gplots)

# png(file="E:/RainfallCompStatistics.png", width=600, height=800, units="px", 
#     res=110)
# Andit Tid
obsM <- at.mean.month
simM <- ATnnr.mo.mean
(NSE <- NSE(simM,obsM))
(RMSE <- rmse(simM,obsM))
(RSR <- rsr(simM,obsM))
(PBIAS <- pbias(simM,obsM))
(ATE <- mae(simM,obsM))
(MSE <- mse(simM,obsM))

statableAT <- round(rbind(NSE, RMSE, RSR, PBIAS, MSE), 2)
DescBothAT <- round(rbind(describe(obsM, skew=FALSE)[,c(2:6,8:11)], 
                          describe(simM, skew=FALSE)[,c(2:6,8:11)]))

# Anjeni
obsM <- aj.mean.month
simM <- AJnnr.mo.mean
(NSE <- NSE(simM,obsM))
(RMSE <- rmse(simM,obsM))
(RSR <- rsr(simM,obsM))
(PBIAS <- pbias(simM,obsM))
(ATE <- mae(simM,obsM))
(MSE <- mse(simM,obsM))

statableAJ <- round(rbind(NSE, RMSE, RSR, PBIAS, MSE), 2)
DescBothAJ <- round(rbind(describe(obsM, skew=FALSE)[,c(2:6,8:11)], 
                          describe(simM, skew=FALSE)[,c(2:6,8:11)]))

# Maybar
obsM <- ma.mean.month
simM <- MAnnr.mo.mean
(NSE <- NSE(simM,obsM))
(RMSE <- rmse(simM,obsM))
(RSR <- rsr(simM,obsM))
(PBIAS <- pbias(simM,obsM))
(ATE <- mae(simM,obsM))
(MSE <- mse(simM,obsM))

statableMA <- round(rbind(NSE, RMSE, RSR, PBIAS, MSE), 2)
DescBothMA <- round(rbind(describe(obsM, skew=FALSE)[,c(2:6,8:11)], 
                          describe(simM, skew=FALSE)[,c(2:6,8:11)]))

# Export monthly stats to Word----
# library(R2wd)
AllStatData <- cbind(statableAT, statableAJ, statableMA)
colnames(AllStatData) <- c("AT", "AJ", "MA")
AllDescData <- rbind(DescBothAT, DescBothAJ, DescBothMA)
row.names(AllDescData) <- c("AT", "ATNNR", "AJ", "AJNNR", "MA", "MANNR")


# Plot the tables on canvas----
nf <- layout(matrix(c(1,2,3,4,5,6),3,2, byrow=TRUE), 
             heights=c(2,2,2), widths=c(1,2))
# layout.show(nf)
# Andit Tid
textplot(statableAT, show.colnames = FALSE, cex=1, halign="left",
         mar=c(.5,.1,.5,.1), cmar=1, valign="center")
mtext("Andit Tid statistics", side = 3, line = 1, font=2)
textplot(DescBothAT, show.colnames=TRUE, cex=1, halign="left",
         mar=c(.5,.1,.5,.1), cmar=1, valign="center")
# Anjeni
textplot(statableAJ, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="center")
mtext("Anjeni statistics", side = 3, line = 1, font=2)
textplot(DescBothAJ, show.colnames=TRUE, cex=1, halign="left",
         mar=c(.5,.1,.5,.1), cmar=1, valign="center")
# Maybar
textplot(statableMA, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="center")
mtext("Maybar statistics", side = 3, line = 1, font=2)
textplot(DescBothMA, show.colnames=TRUE, cex=1, halign="left",
         mar=c(.5,.1,.5,.1), cmar=1, valign="center")

# dev.off()

#****************************************************************
#****************************************************************
# Seasonal comparison SCRP and CFSR----
#****************************************************************
# Seasonal Analysis Andit Tid
AT.DJFM <- dm2seasonal(at.zoo, season="DJFM", FUN=sum, na.rm=FALSE)
AT.AM <- dm2seasonal(at.zoo, season="AM", FUN=sum, na.rm=FALSE)
AT.JJAS <- dm2seasonal(at.zoo, season="JJAS", FUN=sum, na.rm=FALSE)
AT.ON <- dm2seasonal(at.zoo, season="ON", FUN=sum, na.rm=FALSE)

date <- seq(from = as.Date("1982-01-01"), to=as.Date("2010-01-01"), "1 year")
AT.ONDJFM <- cbind(ON=as.data.frame(AT.ON),DJFM=as.data.frame(coredata(AT.DJFM)))
AT.ONDJFM$Sum <- rowSums(AT.ONDJFM, na.rm = FALSE)
AT.ONDJFM <- AT.ONDJFM$Sum
AT.ONDJFM <- cbind(as.data.frame(as.Date(date)), AT.ONDJFM)
AT.ONDJFM <- read.zoo(AT.ONDJFM, freq=1)

# Seasonal Analysis CFSR
ATnnr.DJFM <- dm2seasonal(ATnnr.zoo, season="DJFM", FUN=sum)
ATnnr.AM <- dm2seasonal(ATnnr.zoo, season="AM", FUN=sum)
ATnnr.JJAS <- dm2seasonal(ATnnr.zoo, season="JJAS", FUN=sum)
ATnnr.ON <- dm2seasonal(ATnnr.zoo, season="ON", FUN=sum)

date <- seq(from = as.Date("1979-01-01"), to=as.Date("2010-01-01"), "1 year")
ATnnr.ONDJFM <- cbind(ON=as.data.frame(ATnnr.ON),DJFM=as.data.frame(coredata(ATnnr.DJFM)))
ATnnr.ONDJFM$Sum <- rowSums(ATnnr.ONDJFM, na.rm=FALSE)
ATnnr.ONDJFM <- ATnnr.ONDJFM$Sum
ATnnr.ONDJFM <- cbind(as.data.frame(as.Date(date)), ATnnr.ONDJFM)
names(ATnnr.ONDJFM) <- c("date", "Sum")
ATnnr.ONDJFM <- read.zoo(ATnnr.ONDJFM, frequency = 1)
rm(ATnnr.DJFM, ATnnr.ON)

#******************************************
# Seasonal analysis Anjeni
AJ.DJFM <- dm2seasonal(aj.zoo, season="DJFM", FUN=sum, na.rm=FALSE)
AJ.AM <- dm2seasonal(aj.zoo, season="AM", FUN=sum, na.rm=FALSE)
AJ.JJAS <- dm2seasonal(aj.zoo, season="JJAS", FUN=sum, na.rm=FALSE)
AJ.ON <- dm2seasonal(aj.zoo, season="ON", FUN=sum, na.rm=FALSE)

date <- seq(from = as.Date("1984-01-01"), to=as.Date("2010-01-01"), "1 year")
AJ.ONDJFM <- cbind(ON=as.data.frame(AJ.ON),DJFM=as.data.frame(coredata(AJ.DJFM)))
AJ.ONDJFM$Sum <- rowSums(AJ.ONDJFM, na.rm=TRUE)
AJ.ONDJFM <- AJ.ONDJFM$Sum
AJ.ONDJFM <- cbind(as.data.frame(as.Date(date)), AJ.ONDJFM)
AJ.ONDJFM <- read.zoo(AJ.ONDJFM, start=1981, freq=1)

# Seasonal Analysis CFSR
AJnnr.DJFM <- dm2seasonal(AJnnr.zoo, season="DJFM", FUN=sum)
AJnnr.AM <- dm2seasonal(AJnnr.zoo, season="AM", FUN=sum)
AJnnr.JJAS <- dm2seasonal(AJnnr.zoo, season="JJAS", FUN=sum)
AJnnr.ON <- dm2seasonal(AJnnr.zoo, season="ON", FUN=sum)

date <- seq(from = as.Date("1979-01-01"), to=as.Date("2010-01-01"), "1 year")
AJnnr.ONDJFM <- cbind(ON=as.data.frame(AJnnr.ON),DJFM=as.data.frame(coredata(AJnnr.DJFM)))
AJnnr.ONDJFM$Sum <- rowSums(AJnnr.ONDJFM, na.rm = TRUE)
AJnnr.ONDJFM <- AJnnr.ONDJFM$Sum
AJnnr.ONDJFM <- cbind(as.data.frame(as.Date(date)), AJnnr.ONDJFM)
names(AJnnr.ONDJFM) <- c("date", "Sum")
AJnnr.ONDJFM <- read.zoo(AJnnr.ONDJFM, frequency = 1)
rm(AJnnr.DJFM, AJnnr.ON, AJ.DJFM, AJ.ON)

#******************************************
# Seasonal analysis Maybar
MA.DJFM <- dm2seasonal(ma.zoo, season="DJFM", FUN=sum, na.rm=FALSE)
MA.AM <- dm2seasonal(ma.zoo, season="AM", FUN=sum, na.rm=FALSE)
MA.JJAS <- dm2seasonal(ma.zoo, season="JJAS", FUN=sum, na.rm=FALSE)
MA.ON <- dm2seasonal(ma.zoo, season="ON", FUN=sum, na.rm=FALSE)

date <- seq(from = as.Date("1981-01-01"), to=as.Date("2010-01-01"), "1 year")
MA.ONDJFM <- cbind(ON=as.data.frame(MA.ON),DJFM=as.data.frame(coredata(MA.DJFM)))
MA.ONDJFM$Sum <- rowSums(MA.ONDJFM, na.rm = TRUE)
MA.ONDJFM <- MA.ONDJFM$Sum
MA.ONDJFM <- cbind(as.data.frame(as.Date(date)), MA.ONDJFM)
MA.ONDJFM <- read.zoo(MA.ONDJFM, start=1981, freq=1)


# Seasonal Analysis CFSR
MAnnr.DJFM <- dm2seasonal(MAnnr.zoo, season="DJFM", FUN=sum, na.rm=FALSE)
MAnnr.AM <- dm2seasonal(MAnnr.zoo, season="AM", FUN=sum, na.rm=FALSE)
MAnnr.JJAS <- dm2seasonal(MAnnr.zoo, season="JJAS", FUN=sum, na.rm=FALSE)
MAnnr.ON <- dm2seasonal(MAnnr.zoo, season="ON", FUN=sum, na.rm=FALSE)

date <- seq(from = as.Date("1979-01-01"), to=as.Date("2010-01-01"), "1 year")
MAnnr.ONDJFM <- cbind(ON=as.data.frame(MAnnr.ON),DJFM=as.data.frame(coredata(MAnnr.DJFM)))
MAnnr.ONDJFM$Sum <- rowSums(MAnnr.ONDJFM, na.rm = TRUE)
MAnnr.ONDJFM <- MAnnr.ONDJFM$Sum
MAnnr.ONDJFM <- cbind(as.data.frame(as.Date(date)), MAnnr.ONDJFM)
names(MAnnr.ONDJFM) <- c("date", "Sum")
MAnnr.ONDJFM <- read.zoo(MAnnr.ONDJFM, frequency = 1)
rm(MAnnr.DJFM, MAnnr.ON, MA.DJFM, MA.ON)


#******************************************************************************
# Plot seasonal analysis on 4 plots----
# Season January, February, March

# Add statistics to plot----
season <- c("ONDJFM", "AM", "JJAS")
station <- c("AT", "AJ", "MA")

for(i in station){
   table <- NULL
   for(j in season){
      obs <- get(paste(i,".", j, sep=""))
      sim <- paste(i,"nnr", ".", j , sep="")
         
      sim <- get(sim)
      sim <- window(sim, start=min(index(obs)), end=max(index(obs)))
         
      (NSE <- NSE(sim,obs, na.rm=TRUE))
      (RMSE <- rmse(sim,obs, na.rm=TRUE))
      (RSR <- rsr(sim,obs, na.rm=TRUE))
      (PBIAS <- pbias(sim,obs, na.rm=TRUE))
      (MAE <- mae(sim,obs, na.rm=TRUE))
      (MSE <- mse(sim,obs, na.rm=TRUE))
         
      stat <- round(rbind(NSE, RMSE, RSR, PBIAS, MAE,MSE), 2)
      table <- cbind(table, stat)
   }
   table <- as.data.frame(table)
   names(table) <- c("ONDJFM", "AM", "JJAS")
   name <- paste("Stat",i,sep="")
   assign(name, table)
}

#******************************************************************************
# Structure according to seasonality and print to LaTex----
#*******************************************************************************

season <- c("ONDJFM", "AM", "JJAS")
station <- c("AT", "AJ", "MA")

for(j in season){
   table <- NULL
   for(i in station){
      obs <- get(paste(i,".", j, sep=""))
      sim <- paste(i,"nnr", ".", j , sep="")
      
      sim <- get(sim)
      sim <- window(sim, start=min(index(obs)), end=max(index(obs)))
      
      (NSE <- NSE(sim,obs, na.rm=TRUE))
      (RMSE <- rmse(sim,obs, na.rm=TRUE))
      (RSR <- rsr(sim,obs, na.rm=TRUE))
      (PBIAS <- pbias(sim,obs, na.rm=TRUE))
      (MAE <- mae(sim,obs, na.rm=TRUE))
      (MSE <- mse(sim,obs, na.rm=TRUE))
      
      stat <- round(rbind(NSE, RMSE, RSR, PBIAS, MAE,MSE), 2)
      table <- cbind(table, stat)
   }
   table <- as.data.frame(table)
   names(table) <- c("Andit Tid", "Anjeni", "Maybar")
   name <- paste("Stat",j,sep="")
   assign(name, table)
}


newobject <- xtable(StatONDJFM)
print.xtable(newobject, type="latex")

newobject <- xtable(StatAM)
print.xtable(newobject, type="latex")

newobject <- xtable(StatJJAS)
print.xtable(newobject, type="latex")






#*******************************************************************************   
#*************************          Yearly Data          ***********************
#*******************************************************************************
# Compare by yearly aggregate----

# pdf(file="W:/10_Papers/11_OwnPapers/Graphs/YearlyRainfall.pdf", onefile=TRUE, paper="a4r", 
#     width=300, height=150)
par(mfrow=c(2,1))
tab <- cbind(at.yrly, ATnnr.yrly)                                         
par(mai=c(1.02,1.1,0.9,0.42))
xl <- c(min(time(ATnnr.yrly)), max(time(ATnnr.yrly)))
yl <- c(0, max(max(ATnnr.yrly), max(at.yrly))+100)
ind <- seq(1, length(ATnnr.yrly))
ins <- seq(0,2500,250)
lab <- format(time(ATnnr.yrly)[ind],"%Y")
plot(at.yrly, col="coral4", xlim=xl,
     main="Annual precipitation measured and simulated\nAndit Tid and CFSR (1984-2004)",
     ylim=c(0,2500), xlab="", lwd=2, xaxt="n", yaxt="n",
     ylab="")
axis(1, at=time(ATnnr.yrly)[ind],labels=lab, las=2)
axis(2, at=ins, labels=ins, las=1)
ticks <- time(ATnnr.yrly)[ind]
abline(h=ins, col="lightgray", lty=3)
abline(v=ticks, col="lightgray", lty=3)                                           
lines(ATnnr.yrly, col="bisque4")

legend("topright", cex=0.7, legend=c("SCRP", "CFSR"),
       col=c("coral4", "antiquewhite3", "antiquewhite4","bisque3","bisque4"),
       lty=1, lwd=c(2,1,1,1,1), bty="n", y.intersp=.7)
text(2900, 2400, paste("Measured annual mean (SCRP): ", 
           round(mean(at.yrly, na.rm=TRUE),2),"mm"), pos=4, cex=0.8, col="coral4")
                                            
text(2900, 2200, paste("Modelled annual mean (CFSR): ",
           round(mean(ATnnr.yrly),2),"mm"), pos=4, cex=0.8, col="bisque4")

# Andit Tid with barplot----
barplot(tab, beside=TRUE, col=c("#8B232335", "#0000CD35"), ylim=c(0,2000),
        main="Yearly rainfall Andit Tid\nSCRP-CFSR",
        ylab="Precipitation [mm]",
        names.arg=lab, las=2)
abline(h=0)
legend(82,2100, c("SCRP", "CFSR"), fill=c("#8B232335", "#0000CD35"),
       cex=.8, bty="n", y.intersp=.7)

#**************************************************
# Anjeni
# par(mai=c(1.02,1.1,0.9,0.42))
# par(mfrow=c(1,1))
xl <- c(min(time(AJnnr.yrly)), max(time(AJnnr.yrly)))
lab <- format(time(AJnnr.yrly)[ind],"%Y")
plot(aj.yrly, col="coral4", xlim=xl,
     main="Annual precipitation measured and simulated\nAnjeni and CFSR (1984-2004)",
     ylim=c(0,5000), xlab="", lwd=2, xaxt="n", yaxt="n",
     ylab="")
ind <- seq(1, length(AJnnr.yrly))
ins <- seq(0,5000,500)
axis(1, at=time(AJnnr.yrly)[ind],labels=lab, las=2)
axis(2, at=ins, labels=ins, las=1)
ticks <- time(AJnnr.yrly)[ind]
abline(h=ins, col="lightgray", lty=3)
abline(v=ticks, col="lightgray", lty=3)
lines(AJnnr.yrly, col="bisque4")

legend("bottomright", cex=0.7, legend=c("SCRP", "CFSR"),
       col=c("coral4", "bisque4"), y.intersp=.6,
       lty=1, lwd=c(2,1,1,1,1), bty="n")
text(2900, 4800, paste("Measured annual mean (SCRP): ", 
                       round(mean(at.yrly, na.rm=TRUE),2),"mm"), pos=4, cex=0.8, col="coral4")

text(2900, 4400, paste("Modelled annual mean (CFSR): ",
                       round(mean(AJnnr.yrly),2),"mm"), pos=4, cex=0.8, col="bisque4")

# Anjeni with barplot----
tab <- cbind(aj.yrly, AJnnr.yrly)
lab <- format(time(AJnnr.yrly), "%Y")
barplot(tab, beside=TRUE, col=c("#8B232335", "#0000CD35"), ylim=c(0,5000),
        main="Yearly rainfall Anjeni\nSCRP-CFSR",
        ylab="Precipitation [mm]",
        names.arg=lab, las=2)
abline(h=0)
legend("topright", c("SCRP", "CFSR"), fill=c("#8B232335", "#0000CD35"),
       cex=.8, bty="n", y.intersp=.6)

#**************************************************
# Maybar
# par(mai=c(1.02,1.1,0.9,0.42))
# par(mfrow=c(1,1))
xl <- c(min(time(MAnnr.yrly)), max(time(MAnnr.yrly)))
lab <- format(time(MAnnr.yrly)[ind],"%Y")
plot(ma.yrly, col="coral4", xlim=xl,
     main="Annual precipitation measured and simulated Maybar\nSCRP and CFSR (1984-2004)",
     ylim=c(0,2500), xlab="", lwd=2, xaxt="n", yaxt="n", ylab="")
ind <- seq(1, length(MAnnr.yrly))
ins <- seq(0,2500,250)
axis(1, at=time(MAnnr.yrly)[ind],labels=lab, las=2)
axis(2, at=ins, labels=ins, las=1)
ticks <- time(MAnnr.yrly)[ind]
abline(h=ins, col="lightgray", lty=3)
abline(v=ticks, col="lightgray", lty=3)
lines(MAnnr.yrly, col="bisque4")

legend("topright", cex=0.7, legend=c("SCRP", "CFSR"),
       col=c("coral4", "bisque4"),
       lty=1, lwd=c(2,1,1,1,1), bty="n")
text(2900, 2400, paste("Measured annual mean (SCRP): ", 
                       round(mean(ma.yrly, na.rm=TRUE),2),"mm"), pos=4, cex=0.8, col="coral4")

text(2900, 2200, paste("Modelled annual mean (CFSR): ",
                       round(mean(MAnnr.yrly),2),"mm"), pos=4, cex=0.8, col="bisque4")

# Anjeni with barplot----
tab <- cbind(ma.yrly, MAnnr.yrly)
lab <- format(time(MAnnr.yrly), "%Y")
barplot(tab, beside=TRUE, col=c("#8B232335", "#0000CD35"), ylim=c(0,2500),
        main="Yearly rainfall Maybar\nSCRP-CFSR",
        ylab="Precipitation [mm]",
        names.arg=lab, las=2)
abline(h=0)
legend("topright", c("SCRP", "CFSR"), fill=c("#8B232335", "#0000CD35"),
       cex=.8, bty="n")
# dev.off()



#****************************************************************************
#****************************************************************************
#****************************************************************************
# Seasonal comparison----
# ONDJFM----

cairo_ps(file="E:/SeasonDryAllStat.eps", width = 12, height = 17, 
         onefile = FALSE, family = "Arial")


maxAT <- max(max(AT.ONDJFM, na.rm=TRUE), max(ATnnr.ONDJFM, na.rm=TRUE))+100
maxAJ <- max(max(AJ.ONDJFM, na.rm=TRUE), max(AJnnr.ONDJFM, na.rm=TRUE))+200
maxMA <- max(max(MA.ONDJFM, na.rm=TRUE), max(MAnnr.ONDJFM, na.rm=TRUE))+200

nf <- layout(matrix(c(1,2,3,4,5,6), 3,2, byrow=FALSE),
             widths=c(4,1), heights=c(1,1,1))
par(mar=c(4, 5, 5, 1), oma=c(2,4,6,3))
# layout.show(nf)

# par(mfrow=c(3,1), mar=c(4,6,4,1))
xl <- c(min(time(ATnnr.ONDJFM)), max(time(ATnnr.ONDJFM)))
plot(AT.ONDJFM, 
     ylim=c(0,maxAT), col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Andit Tid")), 3, .5, cex=1.5)
lines(ATnnr.ONDJFM, col="green4", lty=1, lwd=3)
ind <- seq(1,length(ATnnr.ONDJFM))
ins <- seq(0,600, 100)
axis(1, at=(time(ATnnr.ONDJFM)[ind]), cex.axis=1.8,
     labels=format(time(ATnnr.ONDJFM)[ind], "%Y"), las=2)
axis(2, at=ins, las=1, cex.axis=1.8)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(ATnnr.ONDJFM)[ind], col="lightgray", lty=3)
legend("topright", legend=c("SCRP", "CFSR"),
       lty=c(1,1), col=c("maroon", "green4"), y.intersp=.8,
       bty="n", cex=1.5, lwd=c(2,2))
title(main="Seasonal comparison \n(Oct-Nov-Dec-Jan-Feb-Mar)", outer=TRUE, 
      cex.main=2.5, line=-1)
# Anjeni
plot(AJ.ONDJFM, 
     ylim=c(0,maxAJ), col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Anjeni")), 3, .5, cex=1.5)
lines(AJnnr.ONDJFM, col="green4", lty=1, lwd=3)
ind <- seq(1,length(AJnnr.ONDJFM))
ins <- seq(0,1200, 100)
axis(1, at=(time(AJnnr.ONDJFM)[ind]), cex.axis=1.8,
     labels=format(time(AJnnr.ONDJFM)[ind], format="%Y"), las=2)
axis(2, at=ins, las=1, cex.axis=1.8)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(AJnnr.ONDJFM)[ind], col="lightgray", lty=3)
legend("topright", legend=c("SCRP", "CFSR"),
       lty=c(1,1), col=c("maroon", "green4"), y.intersp=.8,
       bty="n", cex=1.5, lwd=c(2,2))
mtext(side=2, "Precipitation [mm]", line=6, cex=2) 
# Maybar
plot(MA.ONDJFM, 
     ylim=c(0,maxMA), col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Maybar")), 3, .5, cex=1.5)
lines(MAnnr.ONDJFM, col="green4", lty=1, lwd=3)
ind <- seq(1,length(MAnnr.ONDJFM))
ins <- seq(0,1200, 100)
axis(1, at=(time(MAnnr.ONDJFM)[ind]), cex.axis=1.8,
     labels=format(time(MAnnr.ONDJFM)[ind], format="%Y"), las=2)
axis(2, at=ins, las=1, cex.axis=1.8,)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(MAnnr.ONDJFM)[ind], col="lightgray", lty=3)
legend("topright", legend=c("SCRP", "CFSR"),
       lty=c(1,1), col=c("maroon", "green4"), y.intersp=.8,
       bty="n", cex=1.5, lwd=c(2,2))


# Add statistics
# par(mfrow=c(1,3))

textplot(StatAT["ONDJFM"],show.colnames = TRUE, cex=1.5, halign="right", 
         mar=c(.5,.5,.5,.5), valign="center")
mtext(side=3, text="Andit Tid\n ONDJFM", line = -2, font=2)
textplot(StatAJ["ONDJFM"],show.colnames = TRUE, cex=1.5, halign="right", 
         mar=c(.5,.5,.5,.5), valign="center")
mtext(side=3, text="Anjeni\n ONDJFM", line = -2, font=2)
textplot(StatMA["ONDJFM"],show.colnames = TRUE, cex=1.5, halign="right", 
         mar=c(.5,.5,.5,.5), valign="center")
mtext(side=3, text="Maybar\n ONDJFM", line = -2, font=2)
dev.off()

#*******************************************************************************                                        
# JJAS----
# par(mfrow=c(3,1), mar=c(4,6,4,1))
cairo_ps(file="E:/SeasonMainRainAllStat.eps", width = 8, height = 11, 
         onefile = FALSE, family = "Arial")

nf <- layout(matrix(c(1,2,3,4,5,6), 3,2, byrow=FALSE),
             widths=c(4,1.5), heights=c(1,1,1))
par(mar=c(4, 6, 5, 3), oma=c(2,4,6,3))
# layout.show(nf)
xl <- as.numeric(c(min(index(ATnnr.JJAS)), max(index(ATnnr.JJAS))))
# Andit Tid
plot(AT.JJAS, 
     ylim=c(0,max(AT.JJAS, na.rm=TRUE)+100), col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Andit Tid")), 3, .5, cex=1.1)
ind <- seq(1,length(ATnnr.JJAS))
ins <- seq(0,max(AT.JJAS, na.rm=TRUE)+100, 100)
axis(1, at=(time(ATnnr.JJAS)[ind]), labels=format(time(ATnnr.JJAS)[ind]), las=2, 
     cex.axis=1.5)
axis(2, at=ins, las=1, cex.axis=1.5)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(AJnnr.JJAS)[ind], col="lightgray", lty=3)
lines(ATnnr.JJAS, col="green4", lty=1, lwd=3)
lines(AT.JJAS, col="maroon", lwd=3)
legend(1979, 2700, legend=c("SCRP", "CFSR"), horiz=TRUE, seg.len=.7,
       lty=1, lwd=3, col=c("maroon", "green4"), x.intersp=-2,
       bty="n", cex=1.5, y.intersp=.8)
title(main="Seasonal comparison \n(Jun-Jul-Aug-Sep)", outer=TRUE, cex.main=2.5, line=-1)

# Anjeni
plot(AJ.JJAS, xlim=xl,
     ylim=c(0,max(max(AJ.JJAS, na.rm=TRUE), max(AJnnr.JJAS, na.rm=TRUE))+100), 
     col="maroon", lwd=3,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Anjeni")), 3, .5, cex=1.1)
ind <- seq(1,length(AJnnr.JJAS))
ins <- seq(0,max(max(AJ.JJAS, na.rm=TRUE), max(AJnnr.JJAS, na.rm=TRUE))+100, 200)
axis(1, at=(time(AJnnr.JJAS)[ind]), labels=format(time(AJnnr.JJAS)[ind]), las=2,
     cex.axis=1.5)
axis(2, at=ins, las=1, cex.axis=1.5)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(AJnnr.JJAS)[ind], col="lightgray", lty=3)
lines(AJnnr.JJAS, col="green4", lty=1, lwd=3)
lines(AJ.JJAS, col="maroon", lty=1, lwd=3)
legend(1979, 3000, legend=c("SCRP", "CFSR"), horiz=TRUE, seg.len=.7,
       lty=1, lwd=3, col=c("maroon", "green4"), x.intersp=-2,
       bty="n", cex=1.5, y.intersp=.8)
mtext(side=2, "Precipitation [mm]", line=.7, cex=2, outer=TRUE) 

# Maybar
plot(MA.JJAS, 
     ylim=c(0,max(max(MA.JJAS, na.rm=TRUE), max(MAnnr.JJAS, na.rm=TRUE))+100), 
     col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Maybar")), 3, .5, cex=1.1)
ind <- seq(1,length(MAnnr.JJAS))
ins <- seq(0,max(max(MA.JJAS, na.rm=TRUE), max(MAnnr.JJAS, na.rm=TRUE))+100, 100)
axis(1, at=(time(AJnnr.JJAS)[ind]), labels=format(time(MAnnr.JJAS)[ind]), las=2, cex.axis=1.5)
axis(2, at=ins, las=1, cex.axis=1.5)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(MAnnr.JJAS)[ind], col="lightgray", lty=3)
lines(MAnnr.JJAS, col="green4", lty=1, lwd=3)
lines(MA.JJAS, col="maroon", lty=1, lwd=3)
legend(1979, 1100, legend=c("SCRP", "CFSR"), horiz=TRUE, seg.len=.7,
       lty=1, lwd=3, col=c("maroon", "green4"), x.intersp=-2,
       bty="n", cex=1.5, y.intersp=.8)

textplot(StatAT["JJAS"], show.colnames = TRUE, cex=1.5, halign="left", 
         mar=c(.5,.5,.5,.5), valign="center")
textplot(StatAJ["JJAS"], show.colnames = TRUE, cex=1.5, halign="left", 
         mar=c(.5,.5,.5,.5), valign="center")
textplot(StatMA["JJAS"], show.colnames = TRUE, cex=1.5, halign="left", 
         mar=c(.5,.5,.5,.5), valign="center")

dev.off()


#*******************************************************************************                                        
# AM----
# par(mfrow=c(3,1), mar=c(4,6,4,1))
cairo_ps(file="E:/SeasonAMAllStat.eps", width = 8, height = 11, 
         onefile = FALSE, family = "Arial")

nf <- layout(matrix(c(1,2,3,4,5,6), 3,2, byrow=FALSE),
             widths=c(4,1.5), heights=c(1,1,1))
par(mar=c(4,6,5,3), oma=c(2,5,6,3))
# layout.show(nf)
xl <- as.numeric(c(min(index(ATnnr.AM)), max(index(ATnnr.AM))))
# Andit Tid
plot(AT.AM, 
     ylim=c(0,max(AT.AM, na.rm=TRUE)+100), col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Andit Tid")), 3, .5, cex=1.1)
ind <- seq(1,length(ATnnr.AM))
ins <- seq(0,max(AT.AM, na.rm=TRUE)+100, 100)
axis(1, at=(time(ATnnr.AM)[ind]), labels=format(time(ATnnr.AM)[ind]), las=2, 
     cex.axis=1.5)
axis(2, at=ins, las=1, cex.axis=1.5)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(AJnnr.AM)[ind], col="lightgray", lty=3)
lines(ATnnr.AM, col="green4", lty=1, lwd=3)
lines(AT.AM, col="maroon", lwd=3)
legend(2003, 1000, legend=c("SCRP", "CFSR"), horiz=TRUE, seg.len=.7,
       lty=1, lwd=3, col=c("maroon", "green4"), x.intersp=-2,
       bty="n", cex=1.5, y.intersp=.8)
title(main="Seasonal comparison \n(Apr-May)", outer=TRUE, cex.main=2.5, line=-1)

# Anjeni
plot(AJ.AM, xlim=xl,
     ylim=c(0,max(max(AJ.AM, na.rm=TRUE), max(AJnnr.AM, na.rm=TRUE))+100), 
     col="maroon", lwd=3,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Anjeni")), 3, .5, cex=1.1)
ind <- seq(1,length(AJnnr.AM))
ins <- seq(0,max(max(AJ.AM, na.rm=TRUE), max(AJnnr.AM, na.rm=TRUE))+100, 200)
axis(1, at=(time(AJnnr.AM)[ind]), labels=format(time(AJnnr.AM)[ind]), 
     las=2, cex.axis=1.5)
axis(2, at=ins, las=1, cex.axis=1.5)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(AJnnr.AM)[ind], col="lightgray", lty=3)
lines(AJnnr.AM, col="green4", lty=1, lwd=3)
lines(AJ.AM, col="maroon", lwd=3)
legend(2003, 1550, legend=c("SCRP", "CFSR"), x.intersp=-2,
       lty=1, col=c("maroon", "green4"), horiz=TRUE, seg.len=.7,
       bty="n", cex=1.5, lwd=3, y.intersp=.8)
mtext(side=2, "Precipitation [mm]", line=2, cex=2, outer=TRUE) 

# Maybar
plot(MA.AM, 
     ylim=c(0,max(max(MA.AM, na.rm=TRUE), max(MAnnr.AM, na.rm=TRUE))+100), 
     col="maroon", lwd=3, xlim=xl,
     xlab="", ylab="", xaxt="n", yaxt="n")
mtext(expression(bold("Maybar")), 3, .5, cex=1.1)
ind <- seq(1,length(MAnnr.AM))
ins <- seq(0,max(max(MA.AM, na.rm=TRUE), max(MAnnr.AM, na.rm=TRUE))+100, 100)
axis(1, at=(time(AJnnr.AM)[ind]), labels=format(time(MAnnr.AM)[ind]), las=2, cex.axis=1.5)
axis(2, at=ins, las=1, cex.axis=1.5)
abline(h=ins, col="lightgray", lty=3)
abline(v=time(MAnnr.AM)[ind], col="lightgray", lty=3)
lines(MAnnr.AM, col="green4", lty=1, lwd=3)
lines(MA.AM, col="maroon", lwd=3)
legend(2003, 900, legend=c("SCRP", "CFSR"), x.intersp=-2, horiz=TRUE,
       lty=1, col=c("maroon", "green4"), seg.len=.7,
       bty="n", cex=1.5, lwd=3, y.intersp=.8)

textplot(StatAT["AM"], show.colnames = TRUE, cex=1.5, halign="left", 
         mar=c(.5,.5,.5,.5), valign="center")
textplot(StatAJ["AM"], show.colnames = TRUE, cex=1.5, halign="left", 
         mar=c(.5,.5,.5,.5), valign="center")
textplot(StatMA["AM"], show.colnames = TRUE, cex=1.5, halign="left", 
         mar=c(.5,.5,.5,.5), valign="center")

dev.off()


#*******************************************************************************
# Export seasonal statistics to word----
# library(R2wd)
# wdGet(T)
# wdTable(StatAT, caption="Statistics of seasonal CFSR-SCRP comparison, Andit Tid", 
#         caption.pos="above", pointsize=9, 
#         align=c("l", rep("r",ncol(StatAT))))
# 
# wdTable(StatAJ, caption="Statistics of seasonal CFSR-SCRP comparison, Anjeni", 
#         caption.pos="above", pointsize=9, 
#         align=c("l", rep("r",ncol(StatAJ))))
# 
# wdTable(StatMA, caption="Statistics of seasonal CFSR-SCRP comparison, Maybar", 
#         caption.pos="above", pointsize=9, 
#         align=c("l", rep("r",ncol(StatMA))))

