#*************************************************#
# Comparing CFSR and SCRP rainfall data  in mm    #
#                                                 #
#*************************************************#
# Author:   V. Roth                               #
# DatD:/2_PaperData     07/08/2014                #
# Adapted:  --                                    #
#*************************************************#


# Load the libraries
library(zoo)
library(hydroGOF)  
library(ggplot2)   
library(xts)   
library(timeSeries)
library(RColorBrewer)
library(plotrix)


#*********************************************************
AJDischObs.mon <- "DataSCRP/2_Anjeni/Discharge"
AJSedObs.mon <- "DataSCRP/2_Anjeni/Sediment"
AJSCRPFld.mon <- "DataCFSR/2_Anjeni/"
# Simulated discharge with conventional rainfall
AJCFSRFld.mon <- "DataCFSR/2_Anjeni/"
# Define the rainfall data sources
AJpcpCFSR <- "DataCFSR/2_Anjeni/"
AJpcpSCRP <- "DataCFSR/2_Anjeni/"

nbrD <- read.csv("E:/DataCFSR/NmbDays.csv", sep=",")                             # Load a list with the number of days per month


#*******************************************************************************
#*******************       Observed discharge data             *****************
#*******************************************************************************
setwd(AJDischObs.mon)
DischObs <- read.csv("AJ_Discharge_Mon.csv")
DischObs$date <- as.Date(DischObs$date, format="%m/%d/%Y")
# AJDischObs <- AJDischObs[c(25:324),]
row.names(DischObs) <- NULL
# Define the NAs
# NAs <- AJDischObs$dischm3 == "-99"
# is.na(AJDischObs$dischm3)[NAs] <- TRUE
# rm(NAs)
# Change discharge from m3 to m per month (Anjeni is 1052000 m2 or 1.052 km2)
DischObs$mMo <- DischObs$discharge/1052000
# Change discharge from m to mm (*1000)
DischObs$mm <- DischObs$mMo*1000
DischObs <- DischObs[, 4]
ts.disch.obs <- ts(DischObs, start=1984, freq=12)




#*******************************************************************************
#***************              SCRP/CFSR discharge              *****************
#*******************************************************************************
# Load the SCRP SWAT time series and adapt them
setwd(AJSCRPFld.mon)
discharge.scrp <- read.table("output.rch", skip=9)
subobs <- subset(discharge.scrp, V4<13)                                          # remove the yearly data at the end of each year
row.names(subobs) <- NULL
discharge.scrp <- subobs[subobs$V2==15,7]                                        # select data from Col 7 for each V2==2
discharge.scrp <- discharge.scrp[1:300]
months <- seq(as.Date("1986-01-01"), as.Date("2010-12-01"), "month")

scrp.discharge <- data.frame(date=months, disch=discharge.scrp)
scrp.discharge <- cbind(scrp.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s


# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
scrp.discharge$m3D <- scrp.discharge$disch*60*60*24
# Change discharge to m^3 per month
scrp.discharge$m3Mo <- scrp.discharge$m3D*scrp.discharge$nbrD
# Change discharge to m per month (Anjeni is 1052000 m2 or 1.052 km2)
scrp.discharge$mMo <- scrp.discharge$m3Mo/1052000
# Change discharge from m to mm (*1000)
scrp.discharge$mm <- scrp.discharge$mMo*1000
scrp.data <- scrp.discharge[, 7]
scrp.discharge <- scrp.discharge[,7]

ts.discharge.scrp <- ts(scrp.data, start=1986, freq=12)


#*************************************************
# Load the CFSR SWAT time series and adapt them
setwd(AJCFSRFld.mon)
discharge.cfsr <- read.table("output.rch", skip=9)
subsim <- subset(discharge.cfsr, V4<13)
row.names(subsim) <- NULL
discharge.cfsr <- subsim[subsim$V2==15,7]

cfsr.discharge <- data.frame(date=months, disch=discharge.cfsr)
cfsr.discharge <- cbind(cfsr.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s


# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
cfsr.discharge$m3D <- cfsr.discharge$disch*60*60*24
# Change discharge to m^3 per month
cfsr.discharge$m3Mo <- cfsr.discharge$m3D*cfsr.discharge$nbrD
# Change discharge to m per month (Anjeni is 1052000 m2 or 1.052 km2)
cfsr.discharge$mMo <- cfsr.discharge$m3Mo/1052000
# Change discharge from m to mm (*1000)
cfsr.discharge$mm <- cfsr.discharge$mMo*1000
cfsr.data <- cfsr.discharge[,7]
cfsr.discharge <- cfsr.discharge[,7]
ts.discharge.cfsr <- ts(cfsr.data, start=1986, freq=12)
# rm(cfsr.discharge)


#*******************************************************************************
#***************              SCRP/CFSR SEDIMENT               *****************
#*******************************************************************************
# Observed Sediment----
# Sediment
setwd(AJSedObs.mon)
AJSedObs <- read.csv("sedloss.monthly.csv", header=TRUE, na.strings="NA")
AJSedObs$date <- as.Date(AJSedObs$date, format="%m/%d/%Y")
# AJSedObs <- AJSedObs[c(61:360),]
row.names(AJSedObs) <- NULL
names(AJSedObs) <- c("date", "sedtons")
AJSedObs$m3 <- AJSedObs$sedtons/0.625
AJSedObs$m <- AJSedObs$m3/(1052000)
AJSedObs$mm <- AJSedObs$m*1000
AJSedObs <- AJSedObs[,c(1,5)]
ts.sed.obs <- ts(AJSedObs[,2], start=c(1984,1), freq=12)


# Change sediment from tons to mm----
# SCRP sediment----
sed.scrp <- subobs[subobs$V2==15, 11]
sed.scrp <- sed.scrp[1:300]

sed.scrp <- data.frame(date=months, sedtons=sed.scrp)
sed.scrp$m3 <- sed.scrp$sedtons/0.625
sed.scrp$m <- sed.scrp$m3/(1052000)
sed.scrp$mm <- sed.scrp$m*1000
sed.scrp <- sed.scrp$mm
# add the mm to the complete df
ts.sed.scrp <- ts(sed.scrp, start=1986, freq=12)


#***************************
# CFSR sediment----
sed.cfsr <- subsim[subsim$V2==15, 11]
sed.cfsr <- data.frame(date=months, sedtons=sed.cfsr)
sed.cfsr$m3 <- sed.cfsr$sedtons/0.625
sed.cfsr$m <- sed.cfsr$m3/(1052000)
sed.cfsr$mm <- sed.cfsr$m*1000
# add the mm to the complete df
sed.cfsr <- sed.cfsr$mm
ts.sed.cfsr <- ts(sed.cfsr, start=1986, freq=12)


#*******************************************************************************
#***************              SCRP/CFSR RAINFALL               *****************
#*******************************************************************************
# Add the rainfall in mm----
# Load SCRP rainfall data
setwd(AJpcpSCRP)
pcp.scrp <- read.csv("AJAllpcp.csv", header=TRUE, na.string="-99")
pcp.scrp$date <- as.Date(pcp.scrp$date, format="%m/%d/%Y")
# Define the NAs
# NAs <- pcp.scrp == -99
# is.na(pcp.scrp)[NAs] <- TRUE
# rm(NAs)

pcp.scrp$mo <- strftime(pcp.scrp$date, "%m")
pcp.scrp$yr <- strftime(pcp.scrp$date, "%Y")
pcp.scrp.monthly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$mo + pcp.scrp$yr, 
                          FUN=sum, na.action="na.pass")
names(pcp.scrp.monthly) <- c("month", "year", "pcp")
ts.pcp.scrpmon <- ts(pcp.scrp.monthly$pcp, start=1984, freq=12)

pcp.scrp.yearly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$yr, FUN=sum, na.action="na.pass")
names(pcp.scrp.yearly) <- c("year", "pcp")
mean.pcp.scrp.yr <- mean(pcp.scrp.yearly$pcp, na.rm=TRUE)


#*******************************************************
# Load the CFSR rainfall data
setwd(AJpcpCFSR)
pcp.cfsr <- read.csv("pcp_4_St_.csv", header=TRUE, na.string="-99")
pcp.cfsr$date <- as.Date(pcp.cfsr$date, format="%Y-%m-%d")
# # Define the NAs
# NAs <- pcp.cfsr == -99
# is.na(pcp.cfsr)[NAs] <- TRUE
# rm(NAs)

#***********************
# Calculate rainfall mean
rain <- pcp.cfsr[, c(2:5)]
rain$mean <- round(rowMeans(rain, na.rm=TRUE),3)
rain <- cbind(date=pcp.cfsr$date, rain)
rain <- na.omit(rain)
row.names(rain) <- NULL
pcp.cfsr.mean <- rain[,c(1,6)]


# Aggregate daily data to monthly data
pcp.cfsr.mean$mo <- strftime(pcp.cfsr.mean$date, "%m")
pcp.cfsr.mean$yr <- strftime(pcp.cfsr.mean$date, "%Y")
pcp.cfsr.monthly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$mo + pcp.cfsr.mean$yr, 
                          FUN=sum, na.action="na.pass")
names(pcp.cfsr.monthly) <- c("month", "year", "pcp")
ts.pcp.cfsrmon <- ts(pcp.cfsr.monthly$pcp, start=1979, freq=12)
# Aggregate to yearly data
pcp.cfsr.yearly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$yr, FUN=sum, na.action="na.pass")
names(pcp.cfsr.yearly) <- c("year", "pcp")
mean.pcp.cfsr.yr <- mean(pcp.cfsr.yearly$pcp, na.rm=TRUE)



#**********************************************************
# Intersect the time series to have one df at the end----
# Create a multiple time series with all rainfall
ts.rainfall <- ts.union(ts.pcp.cfsrmon, ts.pcp.scrpmon, na.pass=TRUE)
rainfall <- as.data.frame(ts.rainfall)
rainfall <- cbind(index(ts.rainfall), rainfall)
rainfall <- rainfall[,c(1:3)]
names(rainfall) <- c("date", "pcp.cfsr", "pcp.scrp")
months <- seq(as.Date("1979-01-01"), as.Date("2010-12-01"), "month")
rainfall$date <- months

#*******************************************************************************
#**********************          Data frame                 ********************
#*******************************************************************************
# AllData <- ts.intersect(ts.rainfall, ts.discharge.cfsr, 
#                         ts.discharge.scrp, ts.disch.obs, ts.sed.cfsr, 
#                         ts.sed.scrp, ts.sed.obs)
AllData <- ts.union(ts.rainfall, 
                    ts.discharge.cfsr, ts.discharge.scrp, ts.disch.obs, 
                    ts.sed.cfsr, ts.sed.scrp, ts.sed.obs)
AllData <- as.data.frame(AllData)
AllData <- AllData[, c(1,2,4,5,6,7,8,9)]
names(AllData) <- c("pcp.cfsr", "pcp.scrp", "Disch.cfsr", "Disch.scrp", "Disch.obs",
                    "Sed.cfsr", "Sed.scrp", "Sed.obs")
AllData <- cbind(index(AllData), AllData)
names(AllData) <- c("date", "pcp.cfsr", "pcp.scrp", "Disch.cfsr", "Disch.scrp", "Disch.obs",
                    "Sed.cfsr", "Sed.scrp", "Sed.obs")
months <- seq(as.Date("1979-01-01"), as.Date("2010-12-31"), "month")
AllData$date <- months
AllData <- AllData[c(85:384),]
rownames(AllData) <- NULL

#*******************************************************************************
#**************************       Prepare matrix data----            ***********
#*******************************************************************************
date <- format(AllData[,1])
# Define number of years
beg <- as.numeric(format(as.yearmon(min(date)), "%Y"))
end <- as.numeric(format(as.yearmon(max(date)), "%Y"))
year <- seq(as.numeric(beg), as.numeric(end), by=1)
yearrain <- seq(1984, 2010,1)
yearrain2 <- seq(1979,2010,1)

# Create CFSR rainfall matrix data----
matrixM <- matrix(ts.pcp.cfsrmon, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- yearrain2
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.cfrs <- matrixM
moMe.pcp.cfsr <- matrix.pcp.cfrs["Mean",]

# Create SCRP rainfall matrix data----
matrixM <- matrix(ts.pcp.scrpmon, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- yearrain
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.scrp <- matrixM
moMe.pcp.scrp <- matrix.pcp.scrp["Mean",]

#**********************************
# Create discharge matrix data----
matrixM <- matrix(DischObs, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- seq(1984, (1984+nrow(matrixM))-1)
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.obs <- matrixM
moMe.disch.obs <- matrix.disch.obs["Mean",]


matrixM <- matrix(cfsr.discharge, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.cfrs <- matrixM
moMe.disch.cfsr <- matrix.disch.cfrs["Mean",]

matrixM <- matrix(scrp.discharge, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.scrp <- matrixM
moMe.disch.scrp <- matrix.disch.scrp["Mean",]

#***********************************
# Prepare soil loss matrix data----
# Observed sediment
matrixM <- matrix(AJSedObs[,2], ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- seq(1984, (1984+nrow(matrixM))-1)
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.obs <- matrixM
moMe.sed.obs <- matrix.sed.obs["Mean",]

matrixM <- matrix(sed.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.cfsr <- matrixM
moMe.sed.cfsr <- matrix.sed.cfsr["Mean",]

matrixM <- matrix(sed.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.scrp <- matrixM
rm(matrixM)
moMe.sed.scrp <- matrix.sed.scrp["Mean",]

MonthlyData <- as.data.frame(cbind(pcpCFSR=moMe.pcp.cfsr, pcpSCRP=moMe.pcp.scrp,
                                   dischCFSR=moMe.disch.cfsr, dischSCRP=moMe.disch.scrp,
                                   sedCFSR=moMe.sed.cfsr, sedSCRP=moMe.sed.scrp))



#*******************************************************************************
#****************          Plotting Monthly Data                   *************
#*******************************************************************************
pcp.cfsr <- AllData[,2]
pcp.scrp <- AllData[,3]
strflw.cfsr <- AllData[,4]
strflw.scrp <- AllData[,5]
strflw.obs <- AllData[,6]
sed.cfsr <- AllData[,7]
sed.scrp <- AllData[,8]
sed.obs <- AllData[,9]
begin=1
endindex=length(date)

yl.sed <- seq(0, max(max(sed.cfsr, na.rm=TRUE), 
                     max(sed.scrp, na.rm=TRUE))+10, by=50)
disch <- seq(0, 900, by=50)

# Statistics for Monthly data
require(psych)
obs <- strflw.obs
sim2 <- strflw.cfsr
sim <- strflw.scrp
(Desc <- round(describe(cbind(CFSR=strflw.cfsr,
                              SCRP=strflw.scrp,
                              Obs=strflw.obs)),2))
Desc <- Desc[,c(3:5, 9,10)]
# Discharge Stats
(NSEdisch <- NSE(sim,obs))
(RMSEdisch <- rmse(sim,obs))
(RSRdisch <- rsr(sim,obs))
(PBIASdisch <- pbias(sim,obs))
(ATEdisch <- mae(sim,obs))
(MSEdisch <- mse(sim,obs))

(NSEdisch2 <- NSE(sim2,obs))
(RMSEdisch2 <- rmse(sim2,obs))
(RSRdisch2 <- rsr(sim2,obs))
(PBIASdisch2 <- pbias(sim2,obs))
(ATEdisch2 <- mae(sim2,obs))
(MSEdisch2 <- mse(sim2,obs))

statdischSCRP <- round(rbind(RSRdisch, RMSEdisch, NSEdisch, PBIASdisch,ATEdisch,MSEdisch), 2)
statdischCFSR <- round(rbind(RSRdisch2, RMSEdisch2, NSEdisch2, PBIASdisch2,ATEdisch2,MSEdisch2), 2)
rownames(statdischSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statdischCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

# Sediment Stats
# Statistics on sediment
obs <- sed.obs
sim <- sed.scrp
sim2 <- sed.cfsr

(NSEsed <- NSE(sim,obs, na.action(na.omit)))
(RMSEsed <- rmse(sim,obs, na.rm=TRUE))
(RSRsed <- rsr(sim,obs, na.rm=TRUE))
(PBIASsed <- pbias(sim,obs, na.rm=TRUE))
(MAEsed <- mae(sim,obs, na.rm=TRUE))
(MSEsed <- mse(sim,obs, na.rm=TRUE))

(NSEsed2 <- NSE(sim2,obs, na.action(na.omit)))
(RMSEsed2 <- rmse(sim2,obs, na.rm=TRUE))
(RSRsed2 <- rsr(sim2,obs, na.rm=TRUE))
(PBIASsed2 <- pbias(sim2,obs, na.rm=TRUE))
(MAEsed2 <- mae(sim2,obs, na.rm=TRUE))
(MSEsed2 <- mse(sim2,obs, na.rm=TRUE))

statSedSCRP <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,MAEsed,MSEsed), 2)
statSedCFSR <- round(rbind(RSRsed2, RMSEsed2, NSEsed2, PBIASsed2,MAEsed2,MSEsed2), 2)
rownames(statSedSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statSedCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
# prepare a color matrix
colset <- matrix(ncol=5, nrow=3, byrow=FALSE, c("brown", "dodgerblue", "green4"))

# Plot streamflow and rainfall data

library(gplots)
nf <- layout(matrix(c(1,1,1,1,1,2,3,4,5,6), 2, 5, byrow = TRUE), widths=c(1,1,1,1,2), height=c(4,2))
# layout.show(nf)
cairo_ps(file="E:/TotalMonthlyAJ.eps", width = 17, height = 12, 
         onefile = FALSE, family = "Helvetica")


par(mar=c(3,7,6,7))
barplot(pcp.cfsr, yaxt = "n", space = NULL, border=NA,
        ylim = rev(c(0, 4*max(pcp.cfsr))),                                     # "rev" stands for "Reverse Element"
        xaxt = "n", col="#A52A2A45")
axis(4, at=seq(0,1200,200), col.axis="gray37", cex.axis=1.5, las=2)

mtext("Precipitation [mm]", 4, line=5, cex=1.2, adj=1, col="gray37")
title(main="Rainfall, sediment loss and discharge \n Anjeni (monthly data 1986-2010)",
      cex.main=2, font=2)
par(new=TRUE)
barplot(pcp.scrp, yaxt="n", space=NULL, border=NA,
        ylim=rev(c(0, 4*max(pcp.cfsr, na.rm=TRUE))),
        xaxt="n", col="#6495ED75")
legend(302, 900, c("CFSR", "WLRC"), fill=c("#A52A2A45","#6495ED75"), 
       bty="n", border=NA, y.intersp=.6, title="Rainfall",
       cex=1.3)
# Plot Sediment
par(new=TRUE)
barplot(sed.obs, yaxt="n", space=NULL, border=NA,
        ylim=c(0,2*max(sed.obs, na.rm=TRUE)), xaxt="n", col="#00640045")
par(new=TRUE)
barplot(sed.cfsr, yaxt="n", space=NULL, border=NA, 
        ylim=c(0,2*max(sed.obs, na.rm=TRUE)), xaxt="n", col="#A52A2A55")
par(new=TRUE)
barplot(sed.scrp, yaxt="n", space=NULL, border=NA,
        ylim=c(0,2*max(sed.obs, na.rm=TRUE)), xaxt="n", col="#6495ED65")
axis(side=4, at=seq(0,3,.5), col.axis="gray37", col="gray37", las=2,
     cex.axis=1.5)
mtext("Sediment loss [mm]", 4, line=5, cex=1.2, col="gray37", adj=0)
legend(302, 3, c("CFSR", "WLRC", "observed"), title="Sediment", bty="n", 
       border=NA, fill=c("#A52A2A45", "#6495ED55", "#00640065"), 
       y.intersp=.7, cex=1.3)
# Plot Streamflow
par(new=TRUE)
plot(strflw.cfsr, col="brown", type="l", lwd=2, lty=1, xaxt="n", ylab="", 
     xlab="date", ylim=c(0,3*max(max(na.omit(strflw.cfsr)),
                                   max(na.omit(strflw.scrp)))), 
     axes=FALSE, yaxs="i")
axis(side=1, at=seq(0,300, length=26), labels=seq(1986,2011,1), 
     col.axis="gray37", col="gray37",las=2, cex.axis=1.5)
abline(v=seq(1,(endindex-begin+1), length=length(year)+1), col="lightgrey", lty=3)

lines(strflw.scrp, col="dodgerblue", lwd=2, lty=1, xaxt="n")
lines(strflw.obs, col="green4", lwd=2, lty=1, xaxt="n")
axis(side=2, at=seq(0,max(disch)+100,100), pos=-5, cex.axis=1.5, 
     las=2, col.axis="gray37", col="gray37")
legend(2, 1800, legend=c("CFSR", "SCRP", "Observed"), lty=1, lwd=2,
       col=c("brown", "dodgerblue", "green4"), bty="n", seg.len=.5, 
       y.intersp=.5, title="Discharge", cex=1.3)
mtext("Discharge [mm]", 2, 3, cex=1.2, col="gray37", adj=0)
dev.off()



# Add Statistics to plot
textplot(statdischCFSR, show.colnames = FALSE, cex=1, halign="left",
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "CFSR vs Obs\nDischarge", col="brown", font=2, cex=1.4)
textplot(statdischSCRP, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "SCRP vs Obs\nDischarge", col="dodgerblue", font=2, cex=1.4)
textplot(statSedCFSR, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "CFSR vs Obs\nSediment", col="brown", font=2, cex=1.4)
textplot(statSedSCRP, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1, valign="bottom")
text(0.5, 0.87, "SCRP vs Obs\nSediment", col="dodgerblue", font=2, cex=1.4)
textplot(Desc, cex=1, halign="left", mar=c(.5,.1,.5,.1), 
         cmar=1, col.rownames=c("brown", "dodgerblue", "green4"),
         col.data=colset)
text(0.5, 0.9, "Descriptive Statistics of discharge", font=2, cex=1.4)


# dev.off()

#*******************************************************************************
#*********************      Plotting Mean Monthly data               ***********
#*******************************************************************************
max <- max(max(moMe.disch.cfsr, na.rm=TRUE), max(moMe.disch.scrp, na.rm=TRUE))
# Statistics on discharge----
obs <- moMe.disch.obs
sim <- moMe.disch.scrp
sim2 <- moMe.disch.cfsr

library(psych)
(Desc <- round(describe(cbind(CFSR=moMe.disch.cfsr,
                              SCRP=moMe.disch.scrp,
                              Obs=moMe.disch.obs)),2))
Desc <- Desc[,c(3:5, 9,10)]

(NSEdisch <- NSE(sim,obs))
(RMSEdisch <- rmse(sim,obs))
(RSRdisch <- rsr(sim,obs))
(PBIASdisch <- pbias(sim,obs))
(ATEdisch <- mae(sim,obs))
(MSEdisch <- mse(sim,obs))

(NSEdisch2 <- NSE(sim2,obs))
(RMSEdisch2 <- rmse(sim2,obs))
(RSRdisch2 <- rsr(sim2,obs))
(PBIASdisch2 <- pbias(sim2,obs))
(ATEdisch2 <- mae(sim2,obs))
(MSEdisch2 <- mse(sim2,obs))

stattableSCRP <- round(rbind(RSRdisch, RMSEdisch, NSEdisch, PBIASdisch,ATEdisch,MSEdisch), 2)
stattableCFSR <- round(rbind(RSRdisch2, RMSEdisch2, NSEdisch2, PBIASdisch2,ATEdisch2,MSEdisch2), 2)
rownames(stattableSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(stattableCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

# Statistics on sediment
obs <- moMe.sed.obs
sim <- moMe.sed.scrp
sim2 <- moMe.sed.cfsr

(NSEsed <- NSE(sim,obs))
(RMSEsed <- rmse(sim,obs))
(RSRsed <- rsr(sim,obs))
(PBIASsed <- pbias(sim,obs))
(MAEsed <- mae(sim,obs))
(MSEsed <- mse(sim,obs))

(NSEsed2 <- NSE(sim2,obs))
(RMSEsed2 <- rmse(sim2,obs))
(RSRsed2 <- rsr(sim2,obs))
(PBIASsed2 <- pbias(sim2,obs))
(MAEsed2 <- mae(sim2,obs))
(MSEsed2 <- mse(sim2,obs))

statSedSCRP <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,MAEsed,MSEsed), 2)
statSedCFSR <- round(rbind(RSRsed2, RMSEsed2, NSEsed2, PBIASsed2,MAEsed2,MSEsed2), 2)
rownames(statSedSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(statSedCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

library(gplots)

# Plot monthly mean data
# Plot discharge data with statistical data----
# cairo_ps(file="E:/MonthlyMeanAJ.eps", width = 11, height = 8, 
#          onefile = FALSE, family = "Arial")
colset <- matrix(ncol=5, nrow=3, byrow=FALSE, c("brown", "dodgerblue", "green4"))



nf <- layout(matrix(c(1,1,1,1,1,2,3,4,5,6), 2, 5, byrow = TRUE), widths=c(1,1,1,1,3), height=c(4,2))
# layout.show(nf)
# prepare a color matrix
# Export to EPS with Cairo
cairo_ps(file="E:/AJMonthlyMeansinMMCairo.eps", width = 17, height = 12, 
         onefile = FALSE, family = "Helvetica")

par(mar=c(4,7,6,7))
barplot(moMe.pcp.cfsr, yaxt="n", space=NULL, border=NA, 
        ylim=rev(c(0,4*800)), 
        xaxt="n", col="#A52A2A45")
axis(side=4, at=seq(0, 1000, by=200), cex.axis=1.3)
mtext(paste("Precipitation [mm]"), 4, line=3.5, adj=1, cex=1.3)
# abline(h=-2, col="gray37")
title(main="Mean monthly values of rainfall, discharge, and sediment loss \n Anjeni (1986-2010)",
      cex.main=2, font=2)
par(new=TRUE)
barplot(moMe.pcp.scrp, yaxt="n", space=NULL, border=NA,
        ylim=rev(c(0,4*800)),
        xaxt="n", col="#6495ED65")
par(new=TRUE)
legend(12, 100, legend=c("CFSR", "WLRC"), fill=c("#A52A2A45", "#6495ED65"), 
       bty="n", seg.len=.3, title="Rainfall", border=NA, cex=2,
       y.intersp=.7)

par(new=TRUE)
barplot(moMe.sed.obs, ylim=c(0, 5*max(moMe.sed.scrp)), col="#00640065", 
        space=NULL, yaxt="n", xaxt="n", border="gray47")
axis(side=4, at=seq(0,1, by=0.25), cex.axis=1.3)
mtext("Sediment [mm]", 4, line=3.5, cex=1.3, adj=0)
par(new=TRUE)
barplot(moMe.sed.cfsr, yaxt="n", space=NULL, border=NA, cex.axis=1.5, cex.names=1.5, 
        ylim=c(0, 5*max(moMe.sed.scrp)), col="#A52A2A45")
par(new=TRUE)
barplot(moMe.sed.scrp, yaxt="n", xaxt="n", space=NULL, border=NA,
        ylim=c(0, 5*max(moMe.sed.scrp)), col="#6495ED55")
par(new=TRUE)
legend(12, 1, legend=c("CFSR", "WLRC", "Observed"), title="Sediment",
       fill=c("#A52A2A45", "#6495ED55", "#00640065"), y.intersp=.7,
       cex=2, bty="n", seg.len=.3, border=c(NA, NA, "gray47"))
abline(h=0, col="gray37")
par(new=TRUE)
plot(moMe.disch.cfsr, col="brown", type="l", lwd=3, lty=1, xaxt="n", 
     ylab="", xlab="", ylim=c(0,1.5*max(max(na.omit(moMe.disch.scrp)),
                                      max(na.omit(moMe.disch.cfsr)))), 
     axes=FALSE)
lines(moMe.disch.scrp, col="dodgerblue", lwd=3, lty=1, xaxt="n")
# Add observed discharge curve if needed
lines(moMe.disch.obs, col="green4", lwd=3, lty=1, xaxt="n")
axis(side=2, at=seq(0, max+50, by = 100), las=2, cex.axis=1.3)
mtext("Discharge [mm]", 2,line=3.7, cex=1.3, adj=0)
legend(1, max(moMe.disch.cfsr)-0.01, legend=c("CFSR", "WLRC", "Observed"), 
       lty=1, col=c("brown", "dodgerblue", "green4"), bty="n", seg.len=.7,
       title="Discharge", lwd=3, y.intersp=.7, cex=2)
dev.off()




# Statistics
textplot(stattableCFSR, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.9, "CFSR vs Obs\nDischarge", col="brown", font=2, cex=1.6)
textplot(stattableSCRP, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.9, "WLRC vs Obs\nDischarge", col="dodgerblue", font=2, cex=1.6)
textplot(statSedCFSR, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.9, "CFSR vs Obs\nSediment", col="brown", font=2, cex=1.6)
textplot(statSedSCRP, show.colnames = FALSE, cex=1, halign="left", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.9, "WLRC vs Obs\nSediment", col="dodgerblue", font=2, cex=1.6)
textplot(Desc, cex=1, halign="left", mar=c(.5,.1,.5,.1), 
         cmar=1, col.rownames=c("brown", "dodgerblue", "green4"),
         col.data=colset)
text(0.5, 0.9, "Descriptive Statistics of discharge", font=2, cex=1.6)

# dev.off()








