#*************************************************#
# Comparing CFSR and WLRC rainfall data  in mm    #
#                                                 #
#*************************************************#
# Author:   V. Roth                               #
# Date:     07/08/2014                            #
# Adapted:  --                                    #
#*************************************************#


# Load the libraries
library(zoo)
library(hydroGOF)
library(EcoHydRology)
library(ggplot2)   
library(xts)   
library(timeSeries)
library(RColorBrewer)
library(plotrix)

# Define the data sources
# WLRC Discharge data

# Define the data sources
# Observed values
AJDischObs.mon <- "E:/DataSCRP/2_Anjeni/Discharge"
AJSedObs.mon <- "E:/DataSCRP/2_Anjeni/Sediment"

# SCRP Discharge data
AJSCRPFld.mon <- "E:/ArcSWAT_Examples/2_Anjeni/"

# Simulated discharge with conventional rainfall
AJCFSRFld.mon <- "E:/ArcSWAT_Examples/2_Anjeni NNR/"


# Define the rainfall data sources
AJpcpCFSR <- "E:/DataCFSR/2_Anjeni/"
AJpcpSCRP <- "E:/DataCFSR/2_Anjeni/"

# Load a list with the number of days per month
nbrD <- read.csv("DataCFSR/NmbDays.csv", sep=",")                     

#*******************************************************************************
#*******************             Observed data                 *****************
#*******************************************************************************
setwd(AJDischObs.mon)
DischObs <- read.csv("AJ_Discharge_Mon.csv")
DischObs$date <- as.Date(DischObs$date, format="%m/%d/%Y")
# AJDischObs <- AJDischObs[c(25:324),]
row.names(DischObs) <- NULL
# Define the NAs
# NAs <- AJDischObs$dischm3 == "-99"
# is.na(AJDischObs$dischm3)[NAs] <- TRUE
# rm(NAs)
# Change discharge from m3 to m per month (Anjeni is 1052000 m2 or 1.052 km2)
DischObs$mMo <- DischObs$discharge/1052000
# Change discharge from m to mm (*1000)
DischObs$mm <- DischObs$mMo*1000
DischObs <- DischObs[, 4]
ts.disch.obs <- ts(DischObs, start=1986, freq=12)


#******************
# Daily discharge for Baseflow calculations----
setwd(AJDischObs.mon)
dischdaily <- read.csv("AJ_Discharge_daily.csv")
dischdaily$date <- as.Date(dischdaily$date, format="%m/%d/%Y")

dischdail.complete <- dischdaily[complete.cases(dischdaily),]
rownames(dischdail.complete) <- NULL
bfs <- BaseflowSeparation(dischdail.complete$discharge, passes=3)
dischdail.complete$bfs <- bfs[,1]
ts.bfs.obs <- ts(dischdail.complete[,c(2,3)], start=1984, freq=365)
ts.all.obs <- ts(dischdaily, start=1984, freq=365)
ts.all.obs <- ts.union(ts.all.obs, ts.bfs.obs)
ts.all.obs <- ts.all.obs[, c(2,4)]
names(ts.all.obs) <- c("discharge", "bfs")








#*******************************************************************************
#***************              SCRP/CFSR discharge              *****************
#*******************************************************************************
# Load the SCRP SWAT time series and adapt them
setwd(AJSCRPFld.mon)
discharge.scrp <- read.table("output.rch", skip=9)
subobs <- subset(discharge.scrp, V4<13)                                          # remove the yearly data at the end of each year
row.names(subobs) <- NULL
discharge.scrp <- subobs[subobs$V2==15,7]                                        # select data from Col 7 for each V2==2
discharge.scrp <- discharge.scrp[1:300]
months <- seq(as.Date("1986-01-01"), as.Date("2010-12-01"), "month")

scrp.discharge <- data.frame(date=months, disch=discharge.scrp)
scrp.discharge <- cbind(scrp.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s
rm(discharge.scrp)

# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
scrp.discharge$m3D <- scrp.discharge$disch*60*60*24
# Change discharge to m^3 per month
scrp.discharge$m3Mo <- scrp.discharge$m3D*scrp.discharge$nbrD
# Change discharge to m per month (Anjeni is 1052000 m2 or 1.052 km2)
scrp.discharge$mMo <- scrp.discharge$m3Mo/1052000
# Change discharge from m to mm (*1000)
scrp.discharge$mm <- scrp.discharge$mMo*1000
scrp.data <- scrp.discharge[, 7]
scrp.discharge <- scrp.discharge[,7]

ts.discharge.scrp <- ts(scrp.data, start=1986, freq=12)


#*************************************************
# Load the CFSR SWAT time series and adapt them
setwd(AJCFSRFld.mon)
discharge.cfsr <- read.table("output.rch", skip=9)
subsim <- subset(discharge.cfsr, V4<13)
row.names(subsim) <- NULL
discharge.cfsr <- subsim[subsim$V2==15,7]

cfsr.discharge <- data.frame(date=months, disch=discharge.cfsr)
cfsr.discharge <- cbind(cfsr.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s


# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
cfsr.discharge$m3D <- cfsr.discharge$disch*60*60*24
# Change discharge to m^3 per month
cfsr.discharge$m3Mo <- cfsr.discharge$m3D*cfsr.discharge$nbrD
# Change discharge to m per month (Anjeni is 1052000 m2 or 1.052 km2)
cfsr.discharge$mMo <- cfsr.discharge$m3Mo/1052000
# Change discharge from m to mm (*1000)
cfsr.discharge$mm <- cfsr.discharge$mMo*1000
cfsr.data <- cfsr.discharge[,7]
cfsr.discharge <- cfsr.discharge[,7]
ts.discharge.cfsr <- ts(cfsr.data, start=1986, freq=12)
# rm(cfsr.discharge)


#*******************************************************************************
#***************              SCRP/CFSR SEDIMENT               *****************
#*******************************************************************************
# Change sediment from tons to mm----
# SCRP sediment----
sed.scrp <- subobs[subobs$V2==15, 11]
sed.scrp <- sed.scrp[1:300]

sed.scrp <- data.frame(date=months, sedtons=sed.scrp)
sed.scrp$m3 <- sed.scrp$sedtons*10
sed.scrp$m <- sed.scrp$m3/(1.052*1000000)
sed.scrp$mm <- sed.scrp$m*1000
# add the mm to the complete df
ts.sed.scrp <- ts(sed.scrp$mm, start=1982, freq=12)
rm(sed.scrp)

# CFSR sediment
sed.cfsr <- subsim[subsim$V2==15, 11]
sed.cfsr <- data.frame(date=months, sedtons=sed.cfsr)
sed.cfsr$m3 <- sed.cfsr$sedtons*10
sed.cfsr$m <- sed.cfsr$m3/(1.052*1000000)
sed.cfsr$mm <- sed.cfsr$m*1000
# add the mm to the complete df
sed.cfsr <- sed.cfsr$mm
ts.sed.cfsr <- ts(sed.cfsr, start=1986, freq=12)
rm(sed.cfsr)

# Observed Sediment----
# Sediment
setwd(AJSedObs.mon)
AJSedObs <- read.csv("sedloss.monthly.csv", header=TRUE)
AJSedObs$date <- as.Date(AJSedObs$date, format="%m/%d/%Y")
# AJSedObs <- AJSedObs[c(61:360),]
row.names(AJSedObs) <- NULL
names(AJSedObs) <- c("date", "sedtons")
AJSedObs$m3 <- AJSedObs$sedtons*10
AJSedObs$m <- AJSedObs$m3/(1.052*1000000)
AJSedObs$mm <- AJSedObs$m*1000
ts.sed.obs <- ts(AJSedObs$mm, start=c(1984,1), freq=12)

#*******************************************************************************
#***************              SCRP/CFSR RAINFALL               *****************
#*******************************************************************************
# Add the rainfall in mm----
# Load SCRP rainfall data
setwd(AJpcpSCRP)
pcp.scrp <- read.csv("AJAllpcp.csv", header=TRUE)
pcp.scrp$date <- as.Date(pcp.scrp$date, format="%m/%d/%Y")
# Define the NAs
NAs <- pcp.scrp == -99
is.na(pcp.scrp)[NAs] <- TRUE
rm(NAs)
pcp.scrp$mo <- strftime(pcp.scrp$date, "%m")
pcp.scrp$yr <- strftime(pcp.scrp$date, "%Y")
pcp.scrp.monthly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$mo + pcp.scrp$yr, 
                              FUN=sum, na.action="na.pass")
names(pcp.scrp.monthly) <- c("month", "year", "pcp")
ts.pcp.scrpmon <- ts(pcp.scrp.monthly$pcp, start=1984, freq=12)

pcp.scrp.yearly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$yr, FUN=sum, na.action="na.pass")
names(pcp.scrp.yearly) <- c("year", "pcp")
mean.pcp.scrp.yr <- mean(pcp.scrp.yearly$pcp, na.rm=TRUE)

daily.pcp.scrp <- ts(pcp.scrp$pcp, start=1984, frequency=365)
#*******************************************************
# Load the CFSR rainfall data
setwd(AJpcpCFSR)
pcp.cfsr <- read.csv("pcp_4_St_.csv", header=TRUE)
pcp.cfsr$date <- as.Date(pcp.cfsr$date, format="%Y-%m-%d")
# Define the NAs
NAs <- pcp.cfsr == -99
is.na(pcp.cfsr)[NAs] <- TRUE
rm(NAs)

#***********************
# Calculate rainfall mean
rain <- pcp.cfsr[, c(2:5)]
rain$mean <- round(rowMeans(rain, na.rm=TRUE),3)
rain <- cbind(date=pcp.cfsr$date, rain)
rain <- na.omit(rain)
row.names(rain) <- NULL
pcp.cfsr.mean <- rain[,c(1,6)]


# Aggregate daily data to monthly data
pcp.cfsr.mean$mo <- strftime(pcp.cfsr.mean$date, "%m")
pcp.cfsr.mean$yr <- strftime(pcp.cfsr.mean$date, "%Y")
pcp.cfsr.monthly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$mo + pcp.cfsr.mean$yr, 
                              FUN=sum, na.action="na.pass")
names(pcp.cfsr.monthly) <- c("month", "year", "pcp")
ts.pcp.cfsrmon <- ts(pcp.cfsr.monthly$pcp, start=1979, freq=12)
# Aggregate to yearly data
pcp.cfsr.yearly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$yr, FUN=sum, na.action="na.pass")
names(pcp.cfsr.yearly) <- c("year", "pcp")
mean.pcp.cfsr.yr <- mean(pcp.cfsr.yearly$pcp, na.rm=TRUE)


#**********************************************************
# Intersect the time series to have one df at the end----
# Create a multiple time series with all rainfall
ts.rainfall <- ts.union(ts.pcp.cfsrmon, ts.pcp.scrpmon, na.pass=TRUE)
rainfall <- as.data.frame(ts.rainfall)
rainfall <- cbind(index(ts.rainfall), rainfall)
rainfall <- rainfall[,c(1:3)]
names(rainfall) <- c("date", "pcp.cfsr", "pcp.scrp")
months <- seq(as.Date("1979-01-01"), as.Date("2010-12-01"), "month")
rainfall$date <- months

#*******************************************************************************
#**********************          Data frame                 ********************
#*******************************************************************************
AllData <- ts.union(ts.rainfall, ts.disch.obs, ts.discharge.cfsr,
                    ts.discharge.scrp,  ts.sed.obs, ts.sed.cfsr, 
                    ts.sed.scrp, na.pass=TRUE)
AllData <- as.data.frame(cbind(date=index(AllData),AllData))
AllData <- AllData[, c(1,2,3,5,6,7,8,9,10)]
# AllData <- cbind(index(AllData), AllData)
names(AllData) <- c("date", "pcp.cfsr", "pcp.scrp", "Disch.obs", "Disch.cfsr", "Disch.scrp","Sed.obs", "Sed.cfsr", "Sed.scrp")
months <- seq(as.Date("1979-01-01"), as.Date("2012-12-31"), "month")
AllData$date <- months

date <- format(AllData[,1])
pcp.cfsr <- AllData[,2]
pcp.scrp <- AllData[,3]
strflw.cfsr <- AllData[,4]
strflw.scrp <- AllData[,5]
sed.cfsr <- AllData[,6]
sed.scrp <- AllData[,7]
begin=1
endindex=length(date)

# Define number of years
beg <- as.numeric(format(as.yearmon(min(date)), "%Y"))
end <- as.numeric(format(as.yearmon(max(date)), "%Y"))
year <- seq(as.numeric(beg), as.numeric(end), by=1)

yl.sed <- seq(0, max(max(sed.cfsr, na.rm=TRUE), 
                     max(sed.scrp, na.rm=TRUE))+10, by=50)
disch <- seq(0, 450, by=50)

#*******************************************************************************
#**************************       Prepare matrix data----            ***********
#*******************************************************************************
# Create rainfall matrix data----
matrixM <- matrix(AllData$pcp.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.cfrs <- matrixM
moMe.pcp.cfsr <- matrix.pcp.cfrs["Mean",]

matrixM <- matrix(AllData$pcp.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.scrp <- matrixM
moMe.pcp.scrp <- matrix.pcp.scrp["Mean",]

# Create discharge matrix data----
matrixM <- matrix(AllData$Disch.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.cfrs <- matrixM
moMe.disch.cfsr <- matrix.disch.cfrs["Mean",]

matrixM <- matrix(AllData$Disch.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.scrp <- matrixM
moMe.disch.scrp <- matrix.disch.scrp["Mean",]

# Prepare soil loss matrix data----
matrixM <- matrix(AllData$Sed.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.cfsr <- matrixM
moMe.sed.cfsr <- matrix.sed.cfsr["Mean",]

matrixM <- matrix(AllData$Sed.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.scrp <- matrixM
rm(matrixM)
moMe.sed.scrp <- matrix.sed.scrp["Mean",]

MonthlyData <- as.data.frame(cbind(pcpCFSR=moMe.pcp.cfsr, pcpSCRP=moMe.pcp.scrp,
                                   dischCFSR=moMe.disch.cfsr, dischSCRP=moMe.disch.scrp,
                                   sedCFSR=moMe.sed.cfsr, sedSCRP=moMe.sed.scrp))

#*******************************************************************************
# Plotting different discharges

maxi <- max(max(ts.discharge.scrp), 
            max(ts.disch.obs, na.rm=TRUE)+0.1*max(ts.disch.obs, na.rm=TRUE),
            max(ts.discharge.cfsr)+0.1*max(ts.discharge.cfsr, na.rm=TRUE))

xlimi <- c(min(min(index(ts.discharge.scrp)), min(index(ts.disch.obs)), na.rm=TRUE),
           max(max(index(ts.discharge.scrp)), max(index(ts.disch.obs)), na.rm=TRUE))


obsDisch <- window(ts.disch.obs, start=min(index(ts.discharge.scrp)), 
                   end=max(index(ts.discharge.scrp)))
simDisch <- ts.discharge.cfsr
simDisch2 <- ts.discharge.scrp

xl <- year
yl <- seq(0, max(max(ts.discharge.scrp, na.rm=TRUE), 
                 max(ts.disch.obs, na.rm=TRUE),
                 max(ts.discharge.cfsr, na.rm=TRUE))+200,100)


# Monthly statistics
library(psych)
(Desc <- round(describe(cbind(simCFSR=simDisch, simSCRP=simDisch2, Obs=obsDisch)),2))
Desc <- Desc[,c(2:5, 9,10,11,12,13)]
(NSEdisch <- NSE(simDisch,obsDisch))
(RMSEdisch <- rmse(simDisch, obsDisch))
(RSRdisch <- rsr(simDisch, obsDisch))
(PBIASdisch <- pbias(simDisch, obsDisch))
(ATEdisch <- mae(simDisch, obsDisch))
(MSEdisch <- mse(simDisch, obsDisch))

(NSEdisch2 <- NSE(simDisch2,obsDisch))
(RMSEdisch2 <- rmse(simDisch2, obsDisch))
(RSRdisch2 <- rsr(simDisch2, obsDisch))
(PBIASdisch2 <- pbias(simDisch2, obsDisch))
(ATEdisch2 <- mae(simDisch2, obsDisch))
(MSEdisch2 <- mse(simDisch2, obsDisch))

stattable <- round(rbind(RSRdisch, RMSEdisch, NSEdisch, PBIASdisch,ATEdisch,MSEdisch), 2)
stattable2 <- round(rbind(RSRdisch2, RMSEdisch2, NSEdisch2, PBIASdisch2, ATEdisch2, MSEdisch2), 2)
rownames(stattable) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
rownames(stattable2) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

#**********************************************
# Plot discharge data with statistical data----
library(gplots)
cairo_ps(file="E:/MonthlyDischargeAJ.eps", width = 17, height = 12, 
         onefile = FALSE, family = "Helvetica")

# nf <- layout(matrix(c(1,1,1,2,3,4), 2, 3, byrow = TRUE), widths=c(1,1,5), height=c(4,2))

# layout.show(nf)
# prepare a color matrix
colset <- matrix(ncol=9, nrow=3, byrow=FALSE, c("green4", "dodgerblue", "brown"))


par(mar=c(4,7,6,1), oma=c(3,2,2,2))
plot(ts.discharge.scrp, col="dodgerblue", xaxt="n", yaxt="n",
     xlab="", ylab="", ylim=c(0,maxi+100), lwd=2,
     xlim=c(1985, max(xl)))
# points(ts.disch.obs, type="l", col="brown", ylim=c(0,450), lwd=2)
# box()
axis(1, at=xl, las=2, cex.axis=1.5)
axis(2, at=yl, las=2, cex.axis=1.5)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2007, 1000, legend=c("Simulated CFSR", "Simulated WLRC", "Observed WLRC"), 
       col=c("brown", "dodgerblue", "green4"), bty="n",cex=1.5, 
       lty=1, lwd=2, y.intersp=.8, seg.len=.8)
title(main="Discharge Anjeni\nObserved vs. simulated",font=2, cex.main=2)
mtext(text="Discharge [mm]", side=2, line=4.5, cex=1.5)

lines(ts.discharge.scrp, type="l", col="dodgerblue", lwd=2)
lines(ts.disch.obs, type="l", col="green4", lwd=2)
lines(ts.discharge.cfsr, type="l", col="brown", lty=1, lwd=2)

textplot(stattable, show.colnames = FALSE, cex=1.2, halign="right", valign="center",
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.78, "CFSR vs Obs", col="green4", cex=2, font=2)
textplot(stattable2, show.colnames = FALSE, cex=1.2, valign="center", 
         mar=c(.5,.1,.5,.1), cmar=1, halign="right")
text(0.5, 0.78, "WLRC vs Obs", col="dodgerblue", cex=2, font=2)
textplot(Desc, cex=1.2, halign="left", mar=c(.5,.1,.5,.1), cmar=1, col.rownames=c("green4", "dodgerblue", "brown"),
         col.data=colset, valign="center")
text(0.5, 0.78, "Descriptive Statistics", cex=2, font=2)
dev.off()

#****************************************************333
# Single plot with WLRC and CFSR----

nf <- layout(matrix(c(1,1,2,3), 2, 2, byrow = TRUE), widths=c(1,3), height=c(4,2))
# layout.show(nf)
# prepare a color matrix
colset <- matrix(ncol=9, nrow=3, byrow=FALSE, c("dodgerblue", "green4", "brown"))


par(mar=c(2,5,4,1))
plot(ts.discharge.scrp, col="dodgerblue", xaxt="n", yaxt="n",
     xlab="", ylab="", ylim=c(0,500), lwd=2,
     main="Discharge Anjeni\nObserved vs. simulated",
     xlim=c(1985, max(xl)))
# points(ts.disch.obs, type="l", col="brown", ylim=c(0,450), lwd=2)
# box()
axis(1, at=xl, las=2)
axis(2, at=yl, las=2)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2008, 500, legend=c("Simulated WLRC", "Observed WLRC"), 
       fill=c("dodgerblue", "brown"), bty="n",cex=.9)

mtext(text="Discharge [mm]", side=2, line=3.5, cex=.8)

lines(ts.discharge.scrp, type="l", col="dodgerblue", lwd=2)
lines(ts.disch.obs, type="l", col="brown", lwd=2)
# lines(ts.discharge.cfsr, type="l", col="green4", lty=1, lwd=2)

textplot(stattable2, show.colnames = FALSE, cex=.9, valign="center", 
         mar=c(.5,.1,.5,.1), cmar=1, halign="right")
text(0.5, 0.88, "WLRC vs Obs", col="dodgerblue", font=2)
textplot(Desc, cex=.9, halign="left", mar=c(.5,.1,.5,.1), cmar=1, col.rownames=c("dodgerblue", "green4", "brown"),
         col.data=colset)
text(0.5, 0.8, "Descriptive Statistics", font=2)

#*****************************************************
# With CFSR data

nf <- layout(matrix(c(1,1,2,3), 2, 2, byrow = TRUE), widths=c(1,3), height=c(4,2))
# layout.show(nf)
# prepare a color matrix
colset <- matrix(ncol=9, nrow=3, byrow=FALSE, c("dodgerblue", "green4", "brown"))


par(mar=c(2,5,4,1))
plot(ts.discharge.cfsr, col="green4", xaxt="n", yaxt="n",
     xlab="", ylab="", ylim=c(0,1000), lwd=2,
     main="Discharge Anjeni\nObserved vs. simulated",
     xlim=c(1985, max(xl)))
# points(ts.disch.obs, type="l", col="brown", ylim=c(0,450), lwd=2)
# box()
axis(1, at=xl, las=2)
axis(2, at=yl, las=2)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2008, 960, legend=c("Simulated CFSR", "Observed WLRC"), 
       fill=c("green4", "brown"), bty="n",cex=.9)

mtext(text="Discharge [mm]", side=2, line=3.5, cex=.8)

# lines(ts.discharge.scrp, type="l", col="dodgerblue", lwd=2)
lines(ts.disch.obs, type="l", col="green4", lwd=2)
lines(ts.discharge.cfsr, type="l", col="brown", lty=1, lwd=2)


textplot(stattable, show.colnames = FALSE, cex=.9, halign="right", valign="center",
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 0.88, "CFSR vs Obs", col="green4", font=2)
textplot(Desc, cex=.9, halign="left", mar=c(.5,.1,.5,.1), cmar=1, col.rownames=c("dodgerblue", "green4", "brown"),
         col.data=colset)
text(0.5, 0.88, "Descriptive Statistics", font=2)





#***************************************************************************************************
#***************************************************************************************************
#***************************************************************************************************
# Plot sediment----

begin <- max(min(index(ts.sed.scrp)), min(index(ts.sed.obs)), min(index(ts.sed.cfsr)))
end <- min(max(index(ts.sed.scrp)), max(index(ts.sed.obs)), max(index(ts.sed.cfsr)))

obsSed <- window(ts.sed.obs, start=begin, end=end)
simSed <- window(ts.sed.scrp, start=begin, end=end)
simSed2 <- window(ts.sed.cfsr, start=begin, end=end)

sedMax <- max(max(obsSed, na.rm=TRUE), max(simSed, na.rm=TRUE), max(simSed2, na.rm=TRUE))

xl <- year
yl <- seq(0, max(max(ts.sed.cfsr, na.rm=TRUE)+2, 
                 max(ts.sed.obs, na.rm=TRUE)+7), 1)

# Monthly sediment statistics----
# library(psych)
(Desc <- round(describe(cbind(CFSR=simSed, SCRP= simSed2, Obs=obsSed)),2))
Desc <- Desc[,c(2:5, 9,10,11,12,13)]
(NSEsed <- NSE(simSed,obsSed, na.rm = TRUE))
(RMSEsed <- rmse(simSed, obsSed))
(RSRsed <- rsr(simSed, obsSed))
(PBIASsed <- pbias(simSed, obsSed))
(ATEsed <- mae(simSed, obsSed))
(MSEsed <- mse(simSed, obsSed))

stattable <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed, ATEsed, MSEsed), 2)
names(statSedSCRP) <- "Anjeni"
rownames(statSedSCRP) <- c("RSR","RMSE",  "NSE", "PBIAS", "MAE", "MSE")
AJSCRP <- statSedSCRP


(NSEsed <- NSE(simSed2,obsSed))
(RMSEsed <- rmse(simSed2, obsSed))
(RSRsed <- rsr(simSed2, obsSed))
(PBIASsed <- pbias(simSed2, obsSed))
(ATEsed <- mae(simSed2, obsSed))
(MSEsed <- mse(simSed2, obsSed))
statSedCFSR <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,ATEsed,MSEsed), 2)
rownames(statSedCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
AJCFSR <- statSedCFSR

# Plot data
cairo_ps(file="E:/AJSedimentMon.eps", width = 15, height = 11, 
         onefile = FALSE, family = "Arial")

# nnf <- layout(matrix(c(1,1,1,2,3,4), 2, 3, byrow = TRUE), widths=c(1,1,5), height=c(4,2))
colset <- matrix(ncol=9, nrow=3, byrow=FALSE, c("dodgerblue", "green4", "brown"))

par(mar=c(4,5,5,1), oma=c(2,2,2,2))
plot(ts.sed.scrp, col="dodgerblue", xaxt="n", yaxt="n", lwd=2, type="h",
     xlab="", ylab="", ylim=c(0,sedMax), 
     xlim=c(min(min(index(ts.sed.scrp)), min(index(ts.sed.obs)), na.rm=TRUE),
            max(max(index(ts.sed.scrp)), max(index(ts.sed.obs)), na.rm=TRUE)))
title(main="Sediment loss Anjeni\nObserved vs. simulated", cex.main=2, font=2)
points(ts.sed.obs, type="h", col="brown", ylim=c(0,450), lwd=2)
# box()
axis(1, at=xl, las=2, cex.axis=1.5)
axis(2, at=yl, las=2, cex.axis=1.5)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2005, 18, legend=c("Simulated CFSR", "Simulated WLRC", "Observed WLRC"), 
       col=c("brown", "dodgerblue", "green4"), bty="n",cex=1.4, 
       lty=1, lwd=2, y.intersp=.9, seg.len=.8)

mtext(text="Sediment loss [mm]", side=2, line=3.5, cex=1.3)
# abline(v=1986, col="gold2", lwd=3)
lines(ts.sed.scrp, type="h", col="dodgerblue", lwd=2)
lines(ts.sed.obs, type="h", col="green4", lwd=2)
lines(ts.sed.cfsr, type="h", col="brown", lty=1, lwd=2)

# textplot(stattable, show.colnames = FALSE, cex=1.3, halign="right", valign="center",
#          mar=c(.5,.1,.5,.1), cmar=1)
# text(0.5, .9, "CFSR vs Obs", col="green4", font=2, cex=2)
# 
# textplot(stattable2, show.colnames=FALSE, cex=1.3, halign="right", valign="center",  
#          mar=c(.5,.1,.5,.1), cmar=1, )
# text(.5, .9, "WLRC vs Obs", col="dodgerblue", font=2, cex=2)
# 
# textplot(Desc, cex=1.3, halign="left", mar=c(.5,.1,.5,.1), cmar=1, 
#          col.rownames=c("dodgerblue", "green4", "brown"), col.data=colset)
# text(0.5, .9, "Descriptive Statistics", font=2, cex=2)

dev.off()

#*******************************************************************************
# Plot monthly mean data

barplot(moMe.sed.scrp, ylim=c(0, 8), col="#1E90FF55")
par(new=TRUE)
# barplot(moMe.sed.obs, ylim=c(0,8), col="#A52A2A35")
# par(new=TRUE)
barplot(moMe.sed.cfsr, ylim=c(0,8), col="#008B0045")
title("Mean monthly sediment loss - Anjeni", font=2)
mtext(side=2, line=2.5, "Sediment loss [mm]")
legend("topright", legend=c("WLRC", "CFSR"), fill=c("#1E90FF55", "#008B0045"),  
       bty="n", cex=.8)

dev.off()
