#*************************************************#
# Comparing CFSR and SCRP rainfall data  in mm    #
#                                                 #
#*************************************************#
# Author:   V. Roth                               #
# DatD:/2_PaperData     07/08/2014                            #
# AdapteD:/2_PaperData  --                                    #
#*************************************************#


# Load the libraries
library(zoo)
library(hydroGOF)
library(EcoHydRology)
library(ggplot2)   
library(xts)   
library(timeSeries)
library(RColorBrewer)
library(plotrix)

# Define the data sources
# SCRP Discharge data

# Define the data sources
# Observed values
MADischObs.mon <- "E:/DataSCRP/3_Maybar/Discharge"
MASedObs.mon <- "E:/DataSCRP/3_Maybar/Sediment loss"

# SCRP Discharge data
MASCRPFld.mon <- "E:/ArcSWAT_Examples/3_Maybar"

# Simulated discharge with conventional rainfall
MACFSRFld.mon <- "E:/ArcSWAT_Examples/3_Maybar NNR"


# Define the rainfall data sources
MApcpCFSR <- "E:/ArcSWAT_Examples/3_Maybar NNR"
MApcpSCRP <- "E:/ArcSWAT_Examples/3_Maybar NNR"


# Load a list with the number of days per month
nbrD <- read.csv("E:/ArcSWAT_Examples/NmbDays.csv", sep=",")                     


#*******************************************************************************
#*******************             Observed data                 *****************
#*******************************************************************************
setwd(MADischObs.mon)
DischObs <- read.csv("MA_Discharge_monthly.csv")
DischObs$date <- as.Date(DischObs$date, format="%m/%d/%Y")
# DischObs <- DischObs[c(49:324),]
row.names(DischObs) <- NULL
# Define the NAs
# NAs <- DischObs$dischm3 == "-99"
# is.na(DischObs$dischm3)[NAs] <- TRUE
# rm(NAs)
# Change discharge from m3 to m per month (Anjeni is 1020000 m2 or 1.020 km2)
DischObs$mMo <- DischObs$dischm3/1020000
# Change discharge from m to mm (*1000)
DischObs$mm <- DischObs$mMo*1000
DischObs <- DischObs[, 4]
ts.disch.obs <- ts(DischObs, start=1982, freq=12)


#******************
# Daily discharge for Baseflow calculations----
setwd(MADischObs.mon)
madischdaily <- read.csv("MA_Discharge_daily.csv")
madischdaily$date <- as.Date(madischdaily$date, format="%m/%d/%Y")
madischdaily <- madischdaily[, c(1,2)]

madischdail.complete <- madischdaily[complete.cases(madischdaily),]
rownames(madischdail.complete) <- NULL
bfs <- BaseflowSeparation(madischdail.complete$discharge, passes=3)
madischdail.complete$bfs <- bfs[,1]
ts.bfs.obs <- ts(madischdail.complete[,c(2,3)], start=1982, freq=365)
# madischdail.complete$pcp <- pcp.scrp



#*******************************************************************************
#***************              SCRP/CFSR discharge              *****************
#*******************************************************************************
# Load the SCRP SWAT time series and adapt them
setwd(MASCRPFld.mon)
discharge.scrp <- read.table("output.rch", skip=9)
subobs <- subset(discharge.scrp, V4<13)                                          # remove the yearly data at the end of each year
row.names(subobs) <- NULL
discharge.scrp <- subobs[subobs$V2==21,7]                                        # select data from Col 7 for each V2==2
discharge.scrp <- discharge.scrp[1:300]
months <- seq(as.Date("1986-01-01"), as.Date("2010-12-01"), "month")

scrp.discharge <- data.frame(date=months, disch=discharge.scrp)
scrp.discharge <- cbind(scrp.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s
rm(discharge.scrp)

# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
scrp.discharge$m3D <- scrp.discharge$disch*60*60*24
# Change discharge to m^3 per month
scrp.discharge$m3Mo <- scrp.discharge$m3D*scrp.discharge$nbrD
# Change discharge to m per month (Anjeni is 1020000 m2 or 1.020 km2)
scrp.discharge$mMo <- scrp.discharge$m3Mo/1020000
# Change discharge from m to mm (*1000)
scrp.discharge$mm <- scrp.discharge$mMo*1000
scrp.data <- scrp.discharge[, 7]
scrp.discharge <- scrp.discharge[,7]

ts.discharge.scrp <- ts(scrp.data, start=1986, freq=12)


#*************************************************
# Load the CFSR SWAT time series and adapt them
setwd(MACFSRFld.mon)
discharge.cfsr <- read.table("output.rch", skip=9)
subsim <- subset(discharge.cfsr, V4<13)
row.names(subsim) <- NULL
discharge.cfsr <- subsim[subsim$V2==21,7]

cfsr.discharge <- data.frame(date=months, disch=discharge.cfsr)
cfsr.discharge <- cbind(cfsr.discharge, nbrD=nbrD$days)                          # Discharge is in m^3/s


# Change discharge from m^3/s to mm----
# Change discharge to m^3 per day
cfsr.discharge$m3D <- cfsr.discharge$disch*60*60*24
# Change discharge to m^3 per month
cfsr.discharge$m3Mo <- cfsr.discharge$m3D*cfsr.discharge$nbrD
# Change discharge to m per month (Anjeni is 1020000 m2 or 1.020 km2)
cfsr.discharge$mMo <- cfsr.discharge$m3Mo/1020000
# Change discharge from m to mm (*1000)
cfsr.discharge$mm <- cfsr.discharge$mMo*1000
cfsr.data <- cfsr.discharge[,7]
cfsr.discharge <- cfsr.discharge[,7]
ts.discharge.cfsr <- ts(cfsr.data, start=1986, freq=12)
# rm(cfsr.discharge)


#*******************************************************************************
#***************              SCRP/CFSR SEDIMENT               *****************
#*******************************************************************************
# Change sediment from tons to mm----
# SCRP sediment----
sed.scrp <- subobs[subobs$V2==21, 11]
sed.scrp <- sed.scrp[1:300]

sed.scrp <- data.frame(date=months, sedtons=sed.scrp)
sed.scrp$m3 <- sed.scrp$sedtons*10
sed.scrp$m <- sed.scrp$m3/(1.020*1000000)
sed.scrp$mm <- sed.scrp$m*1000
# add the mm to the complete df
ts.sed.scrp <- ts(sed.scrp$mm, start=1986, freq=12)
rm(sed.scrp)

# CFSR sediment
sed.cfsr <- subsim[subsim$V2==21, 11]
sed.cfsr <- data.frame(date=months, sedtons=sed.cfsr)
sed.cfsr$m3 <- sed.cfsr$sedtons*10
sed.cfsr$m <- sed.cfsr$m3/(1.020*1000000)
sed.cfsr$mm <- sed.cfsr$m*1000
# add the mm to the complete df
sed.cfsr <- sed.cfsr$mm
ts.sed.cfsr <- ts(sed.cfsr, start=1986, freq=12)
rm(sed.cfsr)

# Observed Sediment----
# Sediment
setwd(MASedObs.mon)
MASedObs <- read.csv("MA_Sedloss_monthly.csv", header=TRUE)
MASedObs$date <- as.Date(MASedObs$date, format="%m/%d/%Y")
# MASedObs <- MASedObs[c(61:360),]
row.names(MASedObs) <- NULL
names(MASedObs) <- c("date", "sedtons")
# Define the NAs
NAs <- MASedObs == -99
is.na(MASedObs)[NAs] <- TRUE
# rm(NAs)
MASedObs$m3 <- MASedObs$sedtons*10
MASedObs$m <- MASedObs$m3/(1.020*1000000)
MASedObs$mm <- MASedObs$m*1000

ts.sed.obs <- ts(MASedObs$mm, start=1981, freq=12)

#*******************************************************************************
#***************              SCRP/CFSR RAINFALL               *****************
#*******************************************************************************
# Add the rainfall in mm----
# Load SCRP rainfall data
setwd(MApcpSCRP)
pcp.scrp <- read.csv("MAAllpcp.csv", header=TRUE)
# pcp.scrp <- read.csv("at.daily.prec812013.csv", header=TRUE)
pcp.scrp$date <- as.Date(pcp.scrp$date, format="%m/%d/%Y")
# Define the NAs
NAs <- pcp.scrp == -99
is.na(pcp.scrp)[NAs] <- TRUE
rm(NAs)
# Aggregate daily to monthly data SCRP----
pcp.scrp$mo <- strftime(pcp.scrp$date, "%m")
pcp.scrp$yr <- strftime(pcp.scrp$date, "%Y")
pcp.scrp.monthly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$mo + pcp.scrp$yr, 
                              FUN=sum, na.action="na.pass")
names(pcp.scrp.monthly) <- c("month", "year", "pcp")
ts.pcp.scrpmon <- ts(pcp.scrp.monthly$pcp, start=1981, freq=12)

pcp.scrp.yearly <- aggregate(pcp.scrp$pcp ~ pcp.scrp$yr, FUN=sum, na.action="na.pass")
names(pcp.scrp.yearly) <- c("year", "pcp")
mean.pcp.scrp.yr <- mean(pcp.scrp.yearly$pcp, na.rm=TRUE)

daily.pcp.scrp <- ts(pcp.scrp$pcp, start=1981, frequency=365)
#*******************************************************
# Load the CFSR rainfall data
setwd(MApcpCFSR)
pcp.cfsr <- read.csv("pcp_6_St_.csv", header=TRUE)
pcp.cfsr$date <- as.Date(pcp.cfsr$date, format="%m/%d/%Y")
# Define the NAs
NAs <- pcp.cfsr == -99
is.na(pcp.cfsr)[NAs] <- TRUE
rm(NAs)

#***********************
# Calculate rainfall mean
rain <- pcp.cfsr[, c(2:7)]
rain$mean <- round(rowMeans(rain, na.rm=TRUE),3)
rain <- cbind(date=pcp.cfsr$date, rain)
rain <- na.omit(rain)
row.names(rain) <- NULL
pcp.cfsr.mean <- rain[,c(1,8)]


# Aggregate daily data to monthly data
pcp.cfsr.mean$mo <- strftime(pcp.cfsr.mean$date, "%m")
pcp.cfsr.mean$yr <- strftime(pcp.cfsr.mean$date, "%Y")
pcp.cfsr.monthly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$mo + pcp.cfsr.mean$yr, 
                              FUN=sum, na.action="na.pass")
names(pcp.cfsr.monthly) <- c("month", "year", "pcp")
ts.pcp.cfsrmon <- ts(pcp.cfsr.monthly$pcp, start=1979, freq=12)
# Aggregate to yearly data
pcp.cfsr.yearly <- aggregate(pcp.cfsr.mean$mean ~ pcp.cfsr.mean$yr, FUN=sum, na.action="na.pass")
names(pcp.cfsr.yearly) <- c("year", "pcp")
mean.pcp.cfsr.yr <- mean(pcp.cfsr.yearly$pcp, na.rm=TRUE)


#**********************************************************
# Intersect the time series to have one df at the end----
# Create a multiple time series with all rainfall
ts.rainfall <- ts.union(ts.pcp.cfsrmon, ts.pcp.scrpmon, na.pass=TRUE)
rainfall <- as.data.frame(ts.rainfall)
rainfall <- cbind(index(ts.rainfall), rainfall)
rainfall <- rainfall[,c(1:3)]
names(rainfall) <- c("date", "pcp.cfsr", "pcp.scrp")
months <- seq(as.Date("1979-01-01"), as.Date("2010-12-01"), "month")
rainfall$date <- months

#*******************************************************************************
#**********************          Data frame                 ********************
#*******************************************************************************
AllData.mts <- ts.union(ts.rainfall, ts.disch.obs, ts.discharge.cfsr, 
                        ts.discharge.scrp,  ts.sed.obs, ts.sed.cfsr, 
                        ts.sed.scrp, na.pass=TRUE)
AllData <- as.data.frame(window(AllData.mts, start=1979))
AllData <- AllData[, c(1,2,4,5,6,7,8,9)]
names(AllData) <- c("pcp.cfsr", "pcp.scrp", "Disch.obs", "Disch.cfsr", "Disch.scrp","Sed.obs", "Sed.cfsr", "Sed.scrp")
AllData <- cbind(index(AllData), AllData)
names(AllData) <- c("date", "pcp.cfsr", "pcp.scrp", "Disch.obs", "Disch.cfsr", "Disch.scrp","Sed.obs", "Sed.cfsr", "Sed.scrp")
months <- seq(as.Date("1979-01-01"), as.Date("2011-12-31"), "month")
AllData$date <- months

date <- format(AllData[,1])
pcp.cfsr <- AllData[,2]
pcp.scrp <- AllData[,3]
strflw.cfsr <- AllData[,4]
strflw.scrp <- AllData[,5]
sed.cfsr <- AllData[,6]
sed.scrp <- AllData[,7]
begin=1
endindex=length(date)

# Define number of years
beg <- as.numeric(format(as.yearmon(min(date)), "%Y"))
end <- as.numeric(format(as.yearmon(max(date)), "%Y"))
year <- seq(as.numeric(beg), as.numeric(end), by=1)

yl.sed <- seq(0, max(max(sed.cfsr, na.rm=TRUE), 
                     max(sed.scrp, na.rm=TRUE))+10, by=50)
disch <- seq(0, 450, by=50)

#*******************************************************************************
#**************************       Prepare matrix data----            ***********
#*******************************************************************************
# Create rainfall matrix data----
matrixM <- matrix(AllData$pcp.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.cfrs <- matrixM
moMe.pcp.cfsr <- matrix.pcp.cfrs["Mean",]

matrixM <- matrix(AllData$pcp.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.pcp.scrp <- matrixM
moMe.pcp.scrp <- matrix.pcp.scrp["Mean",]

# Create discharge matrix data----
matrixM <- matrix(AllData$Disch.obs, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.obs <- matrixM
moMe.disch.obs <- matrix.disch.obs["Mean",]

matrixM <- matrix(AllData$Disch.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.cfrs <- matrixM
moMe.disch.cfsr <- matrix.disch.cfrs["Mean",]

matrixM <- matrix(AllData$Disch.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.disch.scrp <- matrixM
moMe.disch.scrp <- matrix.disch.scrp["Mean",]

# Prepare soil loss matrix data----
matrixM <- matrix(round(AllData$Sed.obs, 2), ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.obs <- matrixM
moMe.sed.obs <- matrix.sed.obs["Mean",]

matrixM <- matrix(AllData$Sed.cfsr, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.cfsr <- matrixM
moMe.sed.cfsr <- matrix.sed.cfsr["Mean",]

matrixM <- matrix(AllData$Sed.scrp, ncol=12, byrow=T)
colnames(matrixM) <- month.abb
rownames(matrixM) <- year
matrixM <- rbind(matrixM, Mean=colMeans(matrixM, na.rm=TRUE))
matrix.sed.scrp <- matrixM
rm(matrixM)
moMe.sed.scrp <- matrix.sed.scrp["Mean",]

MonthlyData <- as.data.frame(cbind(pcpCFSR=moMe.pcp.cfsr, pcpSCRP=moMe.pcp.scrp,
                                   dischObs=moMe.disch.obs, dischCFSR=moMe.disch.cfsr, dischSCRP=moMe.disch.scrp,
                                   sedObs=moMe.sed.obs, sedCFSR=moMe.sed.cfsr, sedSCRP=moMe.sed.scrp))

#***************************************************************************************************
#****************************             DISCHARGE                     ****************************
#***************************************************************************************************
# Plotting different discharges----

obsDisch <- window(ts.disch.obs, start=min(index(ts.discharge.scrp)), 
                   end=max(index(ts.discharge.scrp)))
simDisch <- ts.discharge.cfsr
simDisch2 <- ts.discharge.scrp

xl <- year
yl <- seq(0, max(max(ts.discharge.scrp, na.rm=TRUE), 
                 max(ts.disch.obs, na.rm=TRUE)+300), 50)

# Monthly statistics
library(psych)
library(gplots)
(Desc <- round(describe(cbind(CFSR=simDisch, SCRP=simDisch2, Obs=obsDisch)),2))
Desc <- Desc[,c(2:5, 9,10,11,12,13)]
# Statistics
(NSEpcp <- NSE(simDisch,obsDisch))
(RMSEpcp <- rmse(simDisch, obsDisch))
(RSRpcp <- rsr(simDisch, obsDisch, na.rm=TRUE))
(PBIASpcp <- pbias(simDisch, obsDisch, na.rm=TRUE))
(ATEpcp <- mae(simDisch, obsDisch))
(MSEpcp <- mse(simDisch, obsDisch))

statDischCFSR <- round(rbind(RSRpcp, RMSEpcp,NSEpcp, PBIASpcp,ATEpcp,MSEpcp), 2)
rownames(statDischCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")

# Statistics
(NSEpcp <- NSE(simDisch2,obsDisch))
(RMSEpcp <- rmse(simDisch2, obsDisch))
(RSRpcp <- rsr(simDisch2, obsDisch))
(PBIASpcp <- pbias(simDisch2, obsDisch))
(ATEpcp <- mae(simDisch2, obsDisch))
(MSEpcp <- mse(simDisch2, obsDisch))

statDischSCRP <- round(rbind(RSRpcp, RMSEpcp, NSEpcp, PBIASpcp,ATEpcp,MSEpcp), 2)
rownames(statDischSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")



# prepare a color matrix
colset <- matrix(ncol=9, nrow=3, byrow=FALSE, c("dodgerblue", "green4", "brown"))
cairo_ps(file="E:/MADischargeMon.eps", width = 11, height = 8, 
         onefile = FALSE, family = "Arial")

# Plot data
nf <- layout(matrix(c(1,1,1,2,3,4), 2, 3, byrow = TRUE), 
             widths=c(1,1,5), height=c(4,2))

par(mar=c(6,7,5,2), oma=c(2,2,2,2))
plot(ts.discharge.scrp, col="dodgerblue", xaxt="n", yaxt="n",
     xlab="", ylab="", ylim=c(0,450), 
     main="Discharge Maybar\nObserved vs. simulated",
     xlim=c(min(min(index(ts.discharge.scrp)), min(index(ts.disch.obs)), na.rm=TRUE),
            max(max(index(ts.discharge.scrp)), max(index(ts.disch.obs)), na.rm=TRUE)))
# box()
axis(1, at=xl, las=2, cex.axis=1.5)
axis(2, at=yl, las=2, cex.axis=1.5)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(1981, 450, legend=c("Simulated CFSR", "Simulated SCRP", "Observed SCRP"), 
       col=c("brown", "dodgerblue", "green4"), lty=1, lwd=1.4, bty="n",cex=1.5,
       y.intersp=.9, seg.len=.8)
mtext(text="Discharge [mm]", side=2, line=4.5, cex=1.5)

lines(ts.discharge.scrp, type="l", col="dodgerblue", lwd=2)
lines(ts.disch.obs, type="l", col="green4", lwd=2)
lines(ts.discharge.cfsr, type="l", col="brown", lty=1, lwd=2)

textplot(statDischCFSR, show.colnames = FALSE, cex=1.1, halign="right", valign="center",
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, .9, "CFSR vs Obs", col="green4", font=2)

textplot(statDischSCRP, show.colnames=FALSE, cex=1.1, halign="right", valign="center", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(.5, .9, "SCRP vs Obs", col="dodgerblue", font=2)

textplot(Desc, cex=1.1, halign="left", mar=c(.5,.1,.5,.1), cmar=1, 
         col.rownames=c("dodgerblue", "green4", "brown"), col.data=colset)
text(0.5, .9, "Descriptive Statistics", font=2)

dev.off()

#*************************************************
# Compare single simulations of Obs vs CFSR or SCRP----

# Plot data
nf <- layout(matrix(c(1,1,2,3), 2, 2, byrow = TRUE), widths=c(1,3), height=c(4,2))

par(mar=c(4,5,5,1))
plot(ts.discharge.scrp, col="dodgerblue", xaxt="n", yaxt="n",
     xlab="", ylab="", ylim=c(0,300), 
     main="Discharge Maybar\nObserved vs. simulated",
     xlim=c(min(min(index(ts.discharge.scrp)), min(index(ts.disch.obs)), na.rm=TRUE),
            max(max(index(ts.discharge.scrp)), max(index(ts.disch.obs)), na.rm=TRUE)))
# box()
axis(1, at=xl, las=2)
axis(2, at=yl, las=2)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2009, 250, legend=c("Simulated SCRP", "Observed SCRP"), 
       fill=c("dodgerblue", "green4", "brown"), bty="n",cex=.8)
mtext(text="Discharge [mm]", side=2, line=3.5)
lines(ts.disch.obs, type="l", col="brown", lwd=2)
lines(ts.discharge.scrp, type="l", col="dodgerblue", lwd=2)

# lines(ts.discharge.cfsr, type="l", col="green4", lty=1, lwd=2)

# textplot(statDischCFSR, show.colnames = FALSE, cex=1.1, halign="right", valign="center",
#          mar=c(.5,.1,.5,.1), cmar=1)
# text(0.5, .9, "CFSR vs Obs", col="green4", font=2)

textplot(statDischSCRP, show.colnames=FALSE, cex=1.1, halign="right", valign="center", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(.5, 1, "SCRP vs Obs", col="dodgerblue", font=2)

textplot(Desc, cex=1.1, halign="left", mar=c(.5,.1,.5,.1), cmar=1, 
         col.rownames=c("dodgerblue", "green4", "brown"), col.data=colset)
text(0.5, 1, "Descriptive Statistics", font=2)

#************************************************
# CFSR data
# Plot data
nf <- layout(matrix(c(1,1,2,3), 2, 2, byrow = TRUE), widths=c(1,3), height=c(4,2))

par(mar=c(4,5,5,1))
plot(ts.discharge.cfsr, col="green4", xaxt="n", yaxt="n",
     xlab="", ylab="", ylim=c(0,300), 
     main="Discharge Maybar\nObserved vs. simulated",
     xlim=c(min(min(index(ts.discharge.scrp)), min(index(ts.disch.obs)), na.rm=TRUE),
            max(max(index(ts.discharge.scrp)), max(index(ts.disch.obs)), na.rm=TRUE)))
# box()
axis(1, at=xl, las=2)
axis(2, at=yl, las=2)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2009, 250, legend=c("Simulated CFSR", "Observed SCRP"), 
       fill=c("green4", "brown"), bty="n",cex=.8)
mtext(text="Discharge [mm]", side=2, line=3.5)
lines(ts.disch.obs, type="l", col="brown", lwd=2)
lines(ts.discharge.cfsr, type="l", col="green4", lwd=2)

textplot(statDischCFSR, show.colnames = FALSE, cex=1.1, halign="right", valign="center",
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, 1, "CFSR vs Obs", col="green4", font=2)

# textplot(statDischSCRP, show.colnames=FALSE, cex=1.1, halign="right", valign="center", 
#          mar=c(.5,.1,.5,.1), cmar=1)
# text(.5, 1, "SCRP vs Obs", col="dodgerblue", font=2)

textplot(Desc, cex=1.1, halign="left", mar=c(.5,.1,.5,.1), cmar=1, 
         col.rownames=c("dodgerblue", "green4", "brown"), col.data=colset)
text(0.5, 1, "Descriptive Statistics", font=2)




#*******************************************************************************
#*********************** Sediment loss                   ***********************
#*******************************************************************************
# Plot sediment
obsSed <- window(ts.sed.obs, start=min(index(ts.sed.scrp)), 
                 end=max(index(ts.sed.scrp)))
simSed <- ts.sed.scrp
simSed2 <- ts.sed.cfsr

xl <- year
yl <- seq(0, max(max(ts.sed.cfsr, na.rm=TRUE)+2, 
                 max(ts.sed.obs, na.rm=TRUE)+2), 1)

# Monthly statistics
library(psych)
(Desc <- round(describe(cbind(SCRP=simSed, CFSR=simSed2, Obs=obsSed)),2))
Desc <- Desc[,c(2:5, 9,10,11,12,13)]

(NSEsed <- NSE(simSed,obsSed))
(RMSEsed <- rmse(simSed, obsSed))
(RSRsed <- rsr(simSed, obsSed))
(PBIASsed <- pbias(simSed, obsSed))
(ATEsed <- mae(simSed, obsSed))
(MSEsed <- mse(simSed, obsSed))
statSedSCRP <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,ATEsed,MSEsed), 2)
rownames(statSedSCRP) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
MASCRP <- statSedSCRP

(NSEsed <- NSE(simSed2,obsSed))
(RMSEsed <- rmse(simSed2, obsSed))
(RSRsed <- rsr(simSed2, obsSed))
(PBIASsed <- pbias(simSed2, obsSed))
(ATEsed <- mae(simSed2, obsSed))
(MSEsed <- mse(simSed2, obsSed))
statSedCFSR <- round(rbind(RSRsed, RMSEsed, NSEsed, PBIASsed,ATEsed,MSEsed), 2)
rownames(statSedCFSR) <- c("RSR", "RMSE", "NSE", "PBIAS", "MAE", "MSE")
MACFSR <- statSedCFSR


# Plot data
cairo_ps(file="E:/MASedimentMon.eps", width = 15, height = 11, 
         onefile = FALSE, family = "Arial")
# nnf <- layout(matrix(c(1,1,1,2,3,4), 2, 3, byrow = TRUE), widths=c(1,1,5), height=c(4,2))
par(mar=c(5,7,5,3), oma=c(2,2,2,2))
plot(ts.sed.scrp, col="dodgerblue", xaxt="n", yaxt="n", type="h",
     xlab="", ylab="", ylim=c(0,26), 
     xlim=c(min(min(index(ts.sed.scrp)), min(index(ts.sed.obs)), na.rm=TRUE),
            max(max(index(ts.sed.scrp)), max(index(ts.sed.obs)), na.rm=TRUE)))
# box()
axis(1, at=xl, las=2, cex.axis=1.5)
axis(2, at=yl, las=2, cex.axis=1.5)
abline(h=yl, v=xl, col="lightgrey", lty=3)
legend(2005, 26, legend=c("Simulated CFSR", "Simulated SCRP", "Observed SCRP"), 
       col=c("brown", "dodgerblue", "green4"), bty="n",cex=1.5, 
       lty=1, lwd=2, y.intersp=.7, seg.len=.8)
mtext(text="Sediment loss [mm]", side=2, line=4.5, cex=1.5)
title(main="Sediment loss Maybar (monthly)\nObserved vs. simulated", cex.main=2, font=2)

lines(ts.sed.scrp, type="h", col="dodgerblue", lwd=2)
lines(ts.sed.obs, type="h", col="green4", lwd=2)
lines(ts.sed.cfsr, type="h", col="brown", lty=1, lwd=2)

textplot(statSedCFSR, show.colnames = FALSE, cex=1.3, halign="right", valign="center",
         mar=c(.5,.1,.5,.1), cmar=1)
text(0.5, .9, "CFSR vs Obs", col="green4", font=2, cex=2)

textplot(statSedSCRP, show.colnames=FALSE, cex=1.3, halign="right", valign="center", 
         mar=c(.5,.1,.5,.1), cmar=1)
text(.5, .9, "SCRP vs Obs", col="dodgerblue", font=2, cex=2)

textplot(Desc, cex=1.3, halign="left", mar=c(.5,.1,.5,.1), cmar=1, 
         col.rownames=c("dodgerblue", "green4", "brown"), col.data=colset)
text(0.5, .9, "Descriptive Statistics", font=2, cex=2)

dev.off()

#*******************************************************************************
# Plot monthly mean data


barplot(moMe.sed.scrp, ylim=c(0, 8), col="#1E90FF55")
par(new=TRUE)
barplot(moMe.sed.obs, ylim=c(0,8), col="#A52A2A35")
par(new=TRUE)
barplot(moMe.sed.cfsr, ylim=c(0,8), col="#008B0045")
mtext(side=2, line=2.5, "Sediment loss [mm]")
title(font=2, "Monthly mean sediment loss - Maybar")

dev.off()




